@@ -11,7 +11,7 @@
 #  License: MIT (see LICENSE file)
 
 from datetime import date
-from functools import lru_cache
+from functools import cache
 from typing import Optional
 
 from holidays.calendars.gregorian import _timedelta
@@ -100,6 +100,8 @@ class _ThaiLunisolar:
     References:
         * <https://web.archive.org/web/20241016080156/https://www.ninenik.com/แนวทางฟังก์ชั่น_php_อย่างง่ายกับการหาวันข้างขึ้นข้างแรม-1021.html>
         * <https://web.archive.org/web/20250119171416/https://www.myhora.com/ปฏิทิน/ปฏิทิน-พ.ศ.2560.aspx>
+        * <https://web.archive.org/web/20250302100842/https://calendar.kunthet.com/#/>
+        * [2025 Khmer Lunar Calendar](https://web.archive.org/web/20250921045847/https://static1.squarespace.com/static/67722f65f2908e531b5f326d/t/678a87776503cc3f8bc538ac/1737131904673/2025Calendar-compressed.pdf)
 
     Example:
 
@@ -293,7 +295,7 @@ class _ThaiLunisolar:
                 f"Unknown calendar name: {calendar}. Use `KHMER_CALENDAR` or `THAI_CALENDAR`."
             )
 
-    @lru_cache
+    @cache
     def _get_start_date(self, year: int) -> Optional[date]:
         """Calculate the start date of that particular Thai Lunar Calendar Year.
 
@@ -320,6 +322,51 @@ class _ThaiLunisolar:
 
         return _timedelta(_ThaiLunisolar.START_DATE, delta_days)
 
+    @cache
+    def buddhist_sabbath_dates(self, year: int) -> set[date]:
+        """Return all Buddhist Sabbath (Uposatha) days in a given Gregorian year.
+
+        This function works independently of the calendar system in use,
+        whether `THAI_CALENDAR` or `KHMER_CALENDAR`.
+
+        Args:
+            year:
+                The Gregorian year.
+
+        Returns:
+            A set of `date` objects representing all Buddhist Sabbath days in the specified
+            Gregorian year. Returns an empty set if the year is outside the supported range.
+        """
+        start_date = self._get_start_date(year)
+        if not start_date:
+            return set()
+
+        # Initializes Thai lunar month lengths.
+        months = [29, 30] * 6
+        if year in _ThaiLunisolar.ATHIKAMAT_YEARS_GREGORIAN:
+            months.insert(7, 30)
+        elif year in _ThaiLunisolar.ATHIKAWAN_YEARS_GREGORIAN:
+            months[6] += 1
+        # Includes first two months of the next Thai lunar year to ensure all Buddhist Sabbaths
+        # in the Gregorian year are captured.
+        months.extend([29, 30])
+
+        buddhist_sabbaths: set[date] = set()
+        day_cursor = start_date
+        for month_days in months:
+            if day_cursor.year > year:
+                break
+            # Buddhist Sabbaths: 8 Waxing, 15 Waxing, 8 Waning, 14/15 Waning.
+            for offset in (7, 14, 22, month_days - 1):
+                buddhist_sabbath = _timedelta(day_cursor, offset)
+                if buddhist_sabbath.year == year:
+                    buddhist_sabbaths.add(buddhist_sabbath)
+                elif buddhist_sabbath.year > year:
+                    break
+            day_cursor = _timedelta(day_cursor, month_days)
+
+        return buddhist_sabbaths
+
     def makha_bucha_date(self, year: int, calendar=None) -> Optional[date]:
         """Calculate the estimated Gregorian date of Makha Bucha.
 
