@@ -32,6 +32,11 @@ class Chad(
     """
 
     country = "TD"
+    # %s (estimated).
+    estimated_label = "%s (estimated)"
+    # %s (observed, estimated).
+    observed_estimated_label = "%s (observed, estimated)"
+    # %s (observed).
     observed_label = "%s (observed)"
     # On 11 August 1960, Chad gained independence from France.
     start_year = 1961
