@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -20,17 +20,17 @@ class Colombia(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
     """Colombia holidays.
 
     References:
-        * [Ley 35 de 1939 (DEC 4)](https://www.funcionpublica.gov.co/eva/gestornormativo/norma_pdf.php?i=86145)
-        * [Decreto 2663 de 1950 (AUG 5)](https://www.suin-juriscol.gov.co/viewDocument.asp?id=1874133)
-        * [Decreto 3743 de 1950 (DEC 20)](https://www.suin-juriscol.gov.co/viewDocument.asp?id=1535683)
-        * [Ley 51 de 1983 (DEC 6)](https://www.funcionpublica.gov.co/eva/gestornormativo/norma.php?i=4954)
+        * [Ley 35 de 1939 (DEC 4)](https://web.archive.org/web/20250429071624/https://www.funcionpublica.gov.co/eva/gestornormativo/norma_pdf.php?i=86145)
+        * [Decreto 2663 de 1950 (AUG 5)](https://web.archive.org/web/20241113003142/https://www.suin-juriscol.gov.co/viewDocument.asp?id=1874133)
+        * [Decreto 3743 de 1950 (DEC 20)](https://web.archive.org/web/20240725032513/http://suin-juriscol.gov.co/viewDocument.asp?id=1535683)
+        * [Ley 51 de 1983 (DEC 6)](https://web.archive.org/web/20250423030608/https://www.funcionpublica.gov.co/eva/gestornormativo/norma.php?i=4954)
 
     A few links below to calendars from the 1980s to demonstrate this law change.
     In 1984 some calendars still use the old rules, presumably because they were printed
     prior to the declaration of law change:
-        * [1981](https://cloud10.todocoleccion.online/calendarios-antiguos/tc/2018/07/02/19/126899607_96874586.jpg)
-        * [1982](https://cloud10.todocoleccion.online/calendarios-antiguos/tc/2016/08/19/12/58620712_34642074.jpg)
-        * [1984](https://cloud10.todocoleccion.online/calendarios-antiguos/tc/2017/07/12/15/92811790_62818054.jpg)
+        * [1981](https://web.archive.org/web/20250427173739/https://cloud10.todocoleccion.online/calendarios-antiguos/tc/2018/07/02/19/126899607_96874586.jpg)
+        * [1982](https://web.archive.org/web/20250427173704/https://cloud10.todocoleccion.online/calendarios-antiguos/tc/2016/08/19/12/58620712_34642074.jpg)
+        * [1984](https://web.archive.org/web/20250427173707/https://cloud10.todocoleccion.online/calendarios-antiguos/tc/2017/07/12/15/92811790_62818054.jpg)
     """
 
     country = "CO"
