@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -20,7 +20,7 @@ class Croatia(HolidayBase, ChristianHolidays, InternationalHolidays):
     """Croatia holidays.
 
     References:
-        * <https://narodne-novine.nn.hr/clanci/sluzbeni/2019_11_110_2212.html>
+        * <https://web.archive.org/web/20250206084954/https://narodne-novine.nn.hr/clanci/sluzbeni/2019_11_110_2212.html>
         * <https://en.wikipedia.org/wiki/Public_holidays_in_Croatia>
         * <https://hr.wikipedia.org/wiki/Blagdani_i_spomendani_u_Hrvatskoj>
 
