@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -16,19 +16,24 @@ from holidays.holiday_base import HolidayBase
 
 
 class Mauritania(HolidayBase, InternationalHolidays, IslamicHolidays):
-    """
+    """Mauritania holidays.
+
     References:
-    - https://en.wikipedia.org/wiki/Public_holidays_in_Mauritania
-    - https://www.timeanddate.com/holidays/mauritania/
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_Mauritania>
+        * <https://web.archive.org/web/20250408205543/https://www.timeanddate.com/holidays/mauritania/>
     """
 
     country = "MR"
+    # %s (estimated).
+    estimated_label = "%s (estimated)"
     weekend = {FRI, SAT}
 
-    def __init__(self, islamic_show_estimated: bool = True, *args, **kwargs):
+    def __init__(self, *args, islamic_show_estimated: bool = True, **kwargs):
         """
-        :param islamic_show_estimated:
-            Whether to add "estimated" label to Islamic holidays name if holiday date is estimated.
+        Args:
+            islamic_show_estimated:
+                Whether to add "estimated" label to Islamic holidays name
+                if holiday date is estimated.
         """
         InternationalHolidays.__init__(self)
         IslamicHolidays.__init__(self, show_estimated=islamic_show_estimated)
