@@ -64,11 +64,17 @@ class Nigeria(
             islamic_show_estimated:
                 Whether to add "estimated" label to Islamic holidays name
                 if holiday date is estimated.
+
+        In Nigeria, the dates of the Islamic calendar usually fall a day later than
+        the corresponding dates in the Umm al-Qura calendar.
         """
         ChristianHolidays.__init__(self)
         InternationalHolidays.__init__(self)
         IslamicHolidays.__init__(
-            self, cls=NigeriaIslamicHolidays, show_estimated=islamic_show_estimated
+            self,
+            cls=NigeriaIslamicHolidays,
+            show_estimated=islamic_show_estimated,
+            calendar_delta_days=+1,
         )
         StaticHolidays.__init__(self, NigeriaStaticHolidays)
         kwargs.setdefault("observed_rule", SAT_SUN_TO_NEXT_WORKDAY)
@@ -147,112 +153,84 @@ class NigeriaIslamicHolidays(_CustomIslamicHolidays):
     # https://web.archive.org/web/20250829051803/https://www.timeanddate.com/holidays/nigeria/id-el-kabir
     EID_AL_ADHA_DATES_CONFIRMED_YEARS = (1979, 2025)
     EID_AL_ADHA_DATES = {
-        1979: (NOV, 1),
-        1980: (OCT, 20),
-        1981: (OCT, 9),
         1982: (SEP, 29),
-        1983: (SEP, 18),
-        1984: (SEP, 6),
-        1985: (AUG, 27),
-        1986: (AUG, 16),
         1987: (AUG, 6),
         1988: (JUL, 25),
-        1989: (JUL, 14),
         1990: (JUL, 4),
-        1991: (JUN, 23),
-        1993: (JUN, 1),
-        1994: (MAY, 21),
-        1995: (MAY, 10),
+        1992: (JUN, 11),
         1996: (APR, 29),
-        1997: (APR, 18),
-        1998: (APR, 8),
-        1999: (MAR, 28),
-        2001: (MAR, 6),
-        2002: (FEB, 23),
-        2003: (FEB, 12),
-        2004: (FEB, 2),
+        2000: (MAR, 16),
+        2005: (JAN, 21),
+        2006: ((JAN, 10), (DEC, 31)),
         2007: (DEC, 19),
-        2008: (DEC, 9),
-        2009: (NOV, 28),
-        2010: (NOV, 17),
-        2011: (NOV, 7),
+        2012: (OCT, 26),
+        2013: (OCT, 15),
         2014: (OCT, 6),
-        2015: (SEP, 24),
-        2016: (SEP, 12),
-        2017: (SEP, 2),
-        2018: (AUG, 22),
-        2019: (AUG, 12),
+        2020: (JUL, 31),
+        2021: (JUL, 20),
+        2022: (JUL, 9),
+        2023: (JUN, 28),
+        2024: (JUN, 16),
+        2025: (JUN, 6),
     }
 
     # https://web.archive.org/web/20250829052410/https://www.timeanddate.com/holidays/nigeria/id-el-fitr
     EID_AL_FITR_DATES_CONFIRMED_YEARS = (1979, 2025)
     EID_AL_FITR_DATES = {
         1979: (AUG, 25),
-        1980: (AUG, 13),
-        1981: (AUG, 2),
         1982: (JUL, 23),
-        1983: (JUL, 12),
-        1985: (JUN, 20),
-        1986: (JUN, 9),
+        1984: (JUN, 30),
         1987: (MAY, 30),
         1988: (MAY, 18),
-        1989: (MAY, 7),
-        1990: (APR, 27),
-        1991: (APR, 16),
-        1993: (MAR, 25),
-        1994: (MAR, 14),
-        1995: (MAR, 3),
+        1992: (APR, 4),
         1996: (FEB, 21),
-        1997: (FEB, 9),
-        1998: (JAN, 30),
-        1999: (JAN, 19),
         2000: ((JAN, 8), (DEC, 28)),
-        2001: (DEC, 17),
-        2002: (DEC, 6),
-        2003: (NOV, 26),
-        2005: (NOV, 4),
-        2006: (OCT, 24),
+        2004: (NOV, 14),
         2007: (OCT, 12),
         2008: (SEP, 29),
-        2009: (SEP, 21),
         2010: (SEP, 9),
-        2012: (AUG, 20),
-        2017: (JUN, 26),
+        2011: (AUG, 30),
+        2013: (AUG, 8),
+        2014: (JUL, 28),
+        2015: (JUL, 17),
+        2016: (JUL, 6),
+        2018: (JUN, 15),
+        2019: (JUN, 4),
+        2020: (MAY, 24),
+        2021: (MAY, 13),
+        2022: (MAY, 2),
+        2023: (APR, 21),
+        2024: (APR, 10),
+        2025: (MAR, 30),
     }
 
     # https://web.archive.org/web/20250829053435/https://www.timeanddate.com/holidays/nigeria/id-el-maulud
     # https://web.archive.org/web/20250829054319/https://pmnewsnigeria.com/2012/02/03/fg-declares-6-feb-public-holiday/
     MAWLID_DATES_CONFIRMED_YEARS = (1979, 2025)
     MAWLID_DATES = {
-        1979: (FEB, 10),
-        1982: ((JAN, 8), (DEC, 28)),
-        1983: (DEC, 17),
+        1980: (JAN, 30),
+        1981: (JAN, 18),
         1984: (DEC, 6),
-        1985: (NOV, 25),
-        1986: (NOV, 15),
-        1987: (NOV, 4),
-        1988: (OCT, 23),
         1989: (OCT, 13),
-        1990: (OCT, 2),
-        1991: (SEP, 21),
-        1992: (SEP, 10),
-        1993: (AUG, 30),
-        1995: (AUG, 9),
-        1996: (JUL, 28),
+        1994: (AUG, 19),
         1997: (JUL, 18),
-        1998: (JUL, 7),
-        2000: (JUN, 15),
-        2003: (MAY, 14),
-        2004: (MAY, 2),
-        2006: (APR, 11),
-        2011: (FEB, 16),
+        1999: (JUN, 26),
+        2001: (JUN, 4),
+        2002: (MAY, 24),
+        2005: (APR, 21),
+        2007: (MAR, 31),
+        2008: (MAR, 20),
+        2009: (MAR, 9),
+        2010: (FEB, 26),
         2012: (FEB, 6),
+        2013: (JAN, 24),
+        2014: (JAN, 13),
         2015: ((JAN, 2), (DEC, 24)),
-        2016: (DEC, 12),
-        2017: (DEC, 1),
-        2021: (OCT, 19),
-        2024: (SEP, 16),
-        2025: (SEP, 5),
+        2018: (NOV, 20),
+        2019: (NOV, 9),
+        2020: (OCT, 29),
+        2022: (OCT, 8),
+        2023: (SEP, 27),
     }
 
 
