@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -19,9 +19,9 @@ class Samoa(HolidayBase, ChristianHolidays, InternationalHolidays):
 
     References:
         * <https://en.wikipedia.org/wiki/Public_holidays_in_Samoa>
-        * <https://www.timeanddate.com/holidays/samoa/>
-        * <https://www.mcil.gov.ws/?attachment_id=6336>
-        * <https://www.paclii.org/ws/legis/consol_act_2020/pha2008163/>
+        * <https://web.archive.org/web/20250407135339/https://www.timeanddate.com/holidays/samoa/>
+        * <https://web.archive.org/web/20240914112255/https://www.mcil.gov.ws/?attachment_id=6336>
+        * <https://web.archive.org/web/20250413020419/http://www.paclii.org/ws/legis/consol_act_2020/pha2008163/>
     """
 
     country = "WS"
