@@ -47,6 +47,25 @@ class Spain(
         * [2024](https://web.archive.org/web/20240401192304/https://www.boe.es/buscar/doc.php?id=BOE-A-2023-22014)
         * [2025](https://web.archive.org/web/20241226214918/https://www.boe.es/buscar/doc.php?id=BOE-A-2024-21316)
 
+    Subdivisions Holidays References:
+        * Navarra:
+            * [2010](https://web.archive.org/web/20250903095706/https://www.lexnavarra.navarra.es/detalle.asp?r=8402)
+            * [2011](https://web.archive.org/web/20250903095217/https://www.lexnavarra.navarra.es/detalle.asp?r=8403)
+            * [2012](https://web.archive.org/web/20250903095133/https://www.lexnavarra.navarra.es/detalle.asp?r=12993)
+            * [2013](https://web.archive.org/web/20250903095136/https://www.lexnavarra.navarra.es/detalle.asp?r=26226)
+            * [2014](https://web.archive.org/web/20250903095123/https://www.lexnavarra.navarra.es/detalle.asp?r=32382)
+            * [2015](https://web.archive.org/web/20250903095257/https://www.lexnavarra.navarra.es/detalle.asp?r=34276)
+            * [2016](https://web.archive.org/web/20250903095302/https://www.lexnavarra.navarra.es/detalle.asp?r=36141)
+            * [2017](https://web.archive.org/web/20250903095306/https://www.lexnavarra.navarra.es/detalle.asp?r=37665)
+            * [2018](https://web.archive.org/web/20170728130845/https://www.lexnavarra.navarra.es/detalle.asp?r=38904)
+            * [2019](https://web.archive.org/web/20250903095819/https://www.lexnavarra.navarra.es/detalle.asp?r=50305)
+            * [2020](https://web.archive.org/web/20250623005808/https://www.lexnavarra.navarra.es/detalle.asp?r=52229)
+            * [2021](https://web.archive.org/web/20250623010750/https://www.lexnavarra.navarra.es/detalle.asp?r=52748)
+            * [2022](https://web.archive.org/web/20250623000851/https://www.lexnavarra.navarra.es/detalle.asp?r=53763)
+            * [2023](https://web.archive.org/web/20250623010106/https://www.lexnavarra.navarra.es/detalle.asp?r=55481)
+            * [2024](https://web.archive.org/web/20250623001355/https://www.lexnavarra.navarra.es/detalle.asp?r=56116)
+            * [2025](https://web.archive.org/web/20250622235218/https://www.lexnavarra.navarra.es/detalle.asp?r=57122)
+
     Holidays checked with official sources for 2010-2025 only.
     """
 
@@ -102,7 +121,7 @@ class Spain(
         "La Rioja": "RI",
         "Valenciana": "VC",
     }
-    supported_languages = ("en_US", "es", "uk")
+    supported_languages = ("ca", "en_US", "es", "uk")
 
     def __init__(self, *args, islamic_show_estimated: bool = True, **kwargs):
         """
@@ -167,7 +186,7 @@ class Spain(
             self._move_holiday(self._add_epiphany_day(tr("Epifanía del Señor")))
 
         # Andalusia Day.
-        self._move_holiday(self._add_holiday_feb_28(tr("Día de Andalucia")))
+        self._move_holiday(self._add_holiday_feb_28(tr("Día de Andalucía")))
 
         # Maundy Thursday.
         self._add_holy_thursday(tr("Jueves Santo"))
@@ -241,7 +260,7 @@ class Spain(
         if self._year in {2010, 2021}:
             self._move_holiday(self._add_assumption_of_mary_day(tr("Asunción de la Virgen")))
 
-        # Asturia Day.
+        # Asturias Day.
         self._move_holiday(self._add_holiday_sep_8(tr("Día de Asturias")))
 
         if self._year in {2014, 2025}:
@@ -282,7 +301,7 @@ class Spain(
             self._add_holiday_jul_28(tr("Día de las Instituciones de Cantabria"))
 
         if self._year not in {2013, 2019, 2024}:
-            # Our Lady of the Bien Aparecida.
+            # Our Lady of Bien Aparecida.
             self._add_holiday_sep_15(tr("La Bien Aparecida"))
 
         if self._year == 2015:
@@ -641,6 +660,9 @@ class Spain(
         if self._year in {2011, 2013, 2015, 2016, 2017} or self._year >= 2022:
             self._add_saint_james_day(tr("Santiago Apóstol"))
 
+        # Saint Francis Xavier's Day.
+        self._move_holiday(self._add_holiday_dec_3(tr("San Francisco Javier")))
+
         if self._year == 2020:
             self._move_holiday(self._add_holiday_dec_6(tr("Día de la Constitución Española")))
 
