@@ -26,6 +26,8 @@ from holidays.calendars.gregorian import (
     OCT,
     NOV,
     DEC,
+    SAT,
+    SUN,
     _timedelta,
 )
 from holidays.constants import ARMED_FORCES, BANK, GOVERNMENT, PUBLIC, SCHOOL, WORKDAY
@@ -199,6 +201,25 @@ class Thailand(ObservedHolidayBase, InternationalHolidays, StaticHolidays, ThaiC
     def _is_observed(self, dt: date) -> bool:
         return 1961 <= self._year <= 1973 or 1995 <= self._year <= 1997 or self._year >= 2001
 
+    def _get_weekend(self, dt: date) -> set[int]:
+        if dt >= date(1959, MAR, 1):
+            # SAT & SUN (Full Day).
+            weekend = {SAT, SUN}
+        elif date(1956, OCT, 1) <= dt <= date(1957, OCT, 6):
+            # Buddhist Sabbath Days and Sun (Full Day).
+            weekend = {SUN}
+            buddhist_sabbath_dates = self._thai_calendar.buddhist_sabbath_dates(dt.year)
+            if dt in buddhist_sabbath_dates:
+                weekend.add(dt.weekday())
+        elif dt >= date(1939, FEB, 28):
+            # SAT from 12:00 onwards and SUN (Full Day).
+            weekend = {SUN}
+        else:
+            # Prior to this, there was no concept of weekend.
+            weekend = set()
+
+        return weekend
+
     def _populate_public_holidays(self):
         # Fixed Date Holidays
 
@@ -660,14 +681,15 @@ class Thailand(ObservedHolidayBase, InternationalHolidays, StaticHolidays, ThaiC
         # **For pre-1941 data, Buddhist Era year starts on APR 1st.
 
         if 1915 <= self._year <= 1925 or self._year >= 1938:
-            name = (
-                # Makha Bucha.
-                tr("วันมาฆบูชา")
-                if self._year >= 1938
-                # Makha Bucha, the Fourfold Assembly Day.
-                else tr("มาฆบูชา จาตุรงฅ์สันนิบาต")
+            self._add_observed(
+                self._add_makha_bucha(
+                    # Makha Bucha.
+                    tr("วันมาฆบูชา")
+                    if self._year >= 1938
+                    # Makha Bucha, the Fourfold Assembly Day.
+                    else tr("มาฆบูชา จาตุรงฅ์สันนิบาต")
+                )
             )
-            self._add_observed(self._add_makha_bucha(name))
 
         # วันวิสาขบูชา
         # Status: In-Use.
