@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -25,8 +25,8 @@ class Ukraine(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Sta
     """Ukraine holidays.
 
     References:
-        * [Labor Code of Ukraine, Art. 73](https://zakon1.rada.gov.ua/laws/show/322-08/paran454#n454)
-        * <https://zakon.rada.gov.ua/laws/show/585-12>
+        * [Labor Code of Ukraine, Art. 73](https://web.archive.org/web/20240607021920/https://zakon1.rada.gov.ua/laws/show/322-08/paran454)
+        * <https://web.archive.org/web/20240612025118/https://zakon.rada.gov.ua/laws/show/585-12>
     """
 
     country = "UA"
@@ -47,16 +47,16 @@ class Ukraine(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Sta
 
     def _is_observed(self, dt: date) -> bool:
         # 27.01.1995: holiday on weekend move to next workday
-        # https://zakon.rada.gov.ua/laws/show/35/95-вр
+        # https://web.archive.org/web/20230731064358/https://zakon.rada.gov.ua/laws/show/35/95-вр#Text
         # 10.01.1998: cancelled
-        # https://zakon.rada.gov.ua/laws/show/785/97-вр
+        # https://web.archive.org/web/20250121184919/https://zakon.rada.gov.ua/laws/show/785/97-вр
         # 23.04.1999: holiday on weekend move to next workday
-        # https://zakon.rada.gov.ua/laws/show/576-14
+        # https://web.archive.org/web/20240315074159/http://zakon.rada.gov.ua/laws/show/576-14
         return date(1995, JAN, 27) <= dt <= date(1998, JAN, 9) or dt >= date(1999, APR, 23)
 
-    def _populate_common(self, is_martial_law: bool = False):
+    def _populate_common(self, *, is_martial_law: bool = False):
         # There is no public holidays in Ukraine during the period of martial law
-        # https://zakon.rada.gov.ua/laws/show/2136-20#n26
+        # https://web.archive.org/web/20250418204733/https://zakon.rada.gov.ua/laws/show/2136-20
         # law is in force from March 15, 2022
         dts_observed = set()
 
@@ -169,53 +169,53 @@ class UkraineStaticHolidays:
     """Ukraine special holidays.
 
     Substituted holidays References:
-        * [1991](https://zakon.rada.gov.ua/laws/show/60-91-%D0%BF)
-        * [1992 [1]](https://zakon.rada.gov.ua/laws/show/202-92-%D0%BF)
-        * [1992 [2]](https://zakon.rada.gov.ua/laws/show/377-91-%D0%BF)
-        * [1993 [1]](https://zakon.rada.gov.ua/laws/show/563-93-%D0%BF)
-        * [1993 [2]](https://zakon.rada.gov.ua/laws/show/725-92-%D0%BF)
-        * [1994](https://zakon.rada.gov.ua/laws/show/98-94-%D0%BF)
-        * [1995 [1]](https://zakon.rada.gov.ua/laws/show/852-95-%D0%BF)
-        * [1995 [2]](https://zakon.rada.gov.ua/laws/show/634-95-%D0%BF)
-        * [1995 [3]](https://zakon.rada.gov.ua/laws/show/266-95-%D0%BF)
-        * [1996](https://zakon.rada.gov.ua/laws/show/424-96-%D0%BF)
-        * [1997 [1]](https://zakon.rada.gov.ua/laws/show/326-97-%D0%BF)
-        * [1997 [2]](https://zakon.rada.gov.ua/laws/show/1547-96-%D0%BF)
-        * [1998](https://zakon.rada.gov.ua/laws/show/1404-97-%D0%BF>)
-        * [1999 [1]](https://zakon.rada.gov.ua/laws/show/1433-99-%D0%BF>)
-        * [1999 [2]](https://zakon.rada.gov.ua/laws/show/558-99-%D0%BF>)
-        * [1999 [3]](https://zakon.rada.gov.ua/laws/show/2070-98-%D0%BF)
-        * [2000 [1]](https://zakon.rada.gov.ua/laws/show/1251-2000-%D0%BF)
-        * [2000 [2]](https://zakon.rada.gov.ua/laws/show/717-2000-%D0%BF)
-        * [2001 [1]](https://zakon.rada.gov.ua/laws/show/138-2001-%D1%80)
-        * [2001 [2]](https://zakon.rada.gov.ua/laws/show/210-2001-%D0%BF)
-        * [2002](https://zakon.rada.gov.ua/laws/show/202-2002-%D1%80)
-        * [2002 - 2003](https:/zakon.rada.gov.ua/laws/show/705-2002-%D1%80)
-        * [2004](https://zakon.rada.gov.ua/laws/show/773-2003-%D1%80)
-        * [2005 [1]](https://zakon.rada.gov.ua/laws/show/936-2004-%D1%80)
-        * [2005 [2]](https://zakon.rada.gov.ua/laws/show/133-2005-%D1%80)
-        * [2006 [1]](https://zakon.rada.gov.ua/laws/show/490-2005-%D1%80)
-        * [2006 [2]](https://zakon.rada.gov.ua/laws/show/562-2005-%D1%80)
-        * [2007](https://zakon.rada.gov.ua/laws/show/612-2006-%D1%80)
-        * [2008 [1]](https://zakon.rada.gov.ua/laws/show/1059-2007-%D1%80)
-        * [2008 [2]](https://zakon.rada.gov.ua/laws/show/538-2008-%D1%80)
-        * [2009](https://zakon.rada.gov.ua/laws/show/1458-2008-%D1%80)
-        * [2010](https://zakon.rada.gov.ua/laws/show/1412-2009-%D1%80)
-        * [2011](https://zakon.rada.gov.ua/laws/show/2130-2010-%D1%80)
-        * [2012](https://zakon.rada.gov.ua/laws/show/1210-2011-%D1%80)
-        * [2013](https://zakon.rada.gov.ua/laws/show/1043-2012-%D1%80)
-        * [2014](https://zakon.rada.gov.ua/laws/show/920-2013-%D1%80)
-        * [2015](https://zakon.rada.gov.ua/laws/show/1084-2014-%D1%80)
-        * [2016](https://zakon.rada.gov.ua/laws/show/1155-2015-%D1%80)
-        * [2017](https://zakon.rada.gov.ua/laws/show/850-2016-%D1%80)
-        * [2018](https://zakon.rada.gov.ua/laws/show/1-2018-%D1%80)
-        * [2019](https://zakon.rada.gov.ua/laws/show/7-2019-%D1%80)
-        * [2020](https://zakon.rada.gov.ua/laws/show/995-2019-%D1%80)
-        * [2021](https://zakon.rada.gov.ua/laws/show/1191-2020-%D1%80)
-        * [2022](https://zakon.rada.gov.ua/laws/show/1004-2021-%D1%80)
+        * [1991](https://web.archive.org/web/20220830105426/https://zakon.rada.gov.ua/laws/show/60-91-п)
+        * [1992 [1]](https://web.archive.org/web/20220816132241/https://zakon.rada.gov.ua/laws/show/202-92-п)
+        * [1992 [2]](https://web.archive.org/web/20220514124422/https://zakon.rada.gov.ua/laws/show/377-91-п)
+        * [1993 [1]](https://web.archive.org/web/20220429231922/https://zakon.rada.gov.ua/laws/show/563-93-п/)
+        * [1993 [2]](https://web.archive.org/web/20220501192004/https://zakon.rada.gov.ua/laws/show/725-92-п/)
+        * [1994](https://web.archive.org/web/20220423134711/https://zakon.rada.gov.ua/laws/show/98-94-п)
+        * [1995 [1]](https://web.archive.org/web/20220416193351/https://zakon.rada.gov.ua/laws/show/852-95-п/)
+        * [1995 [2]](https://web.archive.org/web/20220727233924/https://zakon.rada.gov.ua/laws/show/634-95-п)
+        * [1995 [3]](https://web.archive.org/web/20220404230852/https://zakon.rada.gov.ua/laws/show/266-95-п)
+        * [1996](https://web.archive.org/web/20220703182454/https://zakon.rada.gov.ua/laws/show/424-96-п)
+        * [1997 [1]](https://web.archive.org/web/20220710133208/https://zakon.rada.gov.ua/laws/show/326-97-п)
+        * [1997 [2]](https://web.archive.org/web/20240707083032/https://zakon.rada.gov.ua/laws/show/1547-96-п)
+        * [1998](https://web.archive.org/web/20220516171244/https://zakon.rada.gov.ua/laws/show/1404-97-п>)
+        * [1999 [1]](https://web.archive.org/web/20220721004702/https://zakon.rada.gov.ua/laws/show/1433-99-п>)
+        * [1999 [2]](https://web.archive.org/web/20220701225902/https://zakon.rada.gov.ua/laws/show/558-99-п>)
+        * [1999 [3]](https://web.archive.org/web/20220703131420/https://zakon.rada.gov.ua/laws/show/2070-98-п)
+        * [2000 [1]](https://web.archive.org/web/20220416193413/https://zakon.rada.gov.ua/laws/show/1251-2000-п/)
+        * [2000 [2]](https://web.archive.org/web/20220404231224/https://zakon.rada.gov.ua/laws/show/717-2000-п)
+        * [2001 [1]](https://web.archive.org/web/20220312201133/https://zakon.rada.gov.ua/laws/show/138-2001-р/)
+        * [2001 [2]](https://web.archive.org/web/20220404230657/https://zakon.rada.gov.ua/laws/show/210-2001-п)
+        * [2002](https://web.archive.org/web/20220521085829/https://zakon.rada.gov.ua/laws/show/202-2002-р)
+        * [2002 - 2003](https://web.archive.org/web/20220312195735/https://zakon.rada.gov.ua/laws/show/705-2002-р)
+        * [2004](https://web.archive.org/web/20220404105708/https://zakon.rada.gov.ua/laws/show/773-2003-р)
+        * [2005 [1]](https://web.archive.org/web/20220521235321/https://zakon.rada.gov.ua/laws/show/936-2004-р)
+        * [2005 [2]](https://web.archive.org/web/20220611030516/https://zakon.rada.gov.ua/laws/show/133-2005-р)
+        * [2006 [1]](https://web.archive.org/web/20240822140051/https://zakon.rada.gov.ua/laws/show/490-2005-р)
+        * [2006 [2]](https://web.archive.org/web/20220312195751/https://zakon.rada.gov.ua/laws/show/562-2005-р/)
+        * [2007](https://web.archive.org/web/20240823064327/https://zakon.rada.gov.ua/laws/show/612-2006-р)
+        * [2008 [1]](https://web.archive.org/web/20240823064327/https://zakon.rada.gov.ua/laws/show/1059-2007-р)
+        * [2008 [2]](https://web.archive.org/web/20240901160821/https://zakon.rada.gov.ua/laws/show/538-2008-р)
+        * [2009](https://web.archive.org/web/20220312195619/https://zakon.rada.gov.ua/laws/show/1458-2008-р/)
+        * [2010](https://web.archive.org/web/20240826001002/https://zakon.rada.gov.ua/laws/show/1412-2009-р)
+        * [2011](https://web.archive.org/web/20220312200622/https://zakon.rada.gov.ua/laws/show/2130-2010-р/)
+        * [2012](https://web.archive.org/web/20250119122439/https://zakon.rada.gov.ua/laws/show/1210-2011-р)
+        * [2013](https://web.archive.org/web/20250119201324/https://zakon.rada.gov.ua/laws/show/1043-2012-р)
+        * [2014](https://web.archive.org/web/20250421100048/https://zakon.rada.gov.ua/laws/show/920-2013-р)
+        * [2015](https://web.archive.org/web/20240801225558/https://zakon.rada.gov.ua/laws/show/1084-2014-р)
+        * [2016](https://web.archive.org/web/20221210054440/https://zakon.rada.gov.ua/laws/show/1155-2015-р)
+        * [2017](https://web.archive.org/web/20240609025258/https://zakon.rada.gov.ua/laws/show/850-2016-р)
+        * [2018](https://web.archive.org/web/20221210060148/https://zakon.rada.gov.ua/laws/show/1-2018-р)
+        * [2019](https://web.archive.org/web/20220316200919/https://zakon.rada.gov.ua/laws/show/7-2019-р)
+        * [2020](https://web.archive.org/web/20250423064733/https://zakon.rada.gov.ua/laws/show/995-2019-р)
+        * [2021](https://web.archive.org/web/20250402142530/https://zakon.rada.gov.ua/laws/show/1191-2020-р)
+        * [2022](https://web.archive.org/web/20250404010912/https://zakon.rada.gov.ua/laws/show/1004-2021-р)
 
     Special holidays References:
-        * [1995](https://zakon.rada.gov.ua/laws/show/13/95)
+        * [1995](https://web.archive.org/web/20220713111605/https://zakon.rada.gov.ua/laws/show/13/95)
     """
 
     # Date format (see strftime() Format Codes)
