@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -14,7 +14,7 @@ from datetime import date
 from gettext import gettext as tr
 
 from holidays.calendars import _CustomIslamicHolidays
-from holidays.calendars.gregorian import JAN, MAR, APR, MAY, JUN, JUL, AUG, SEP, OCT, NOV, DEC
+from holidays.calendars.gregorian import JAN, MAR, APR, MAY, JUN, JUL, AUG, SEP, DEC
 from holidays.groups import InternationalHolidays, IslamicHolidays, StaticHolidays
 from holidays.observed_holiday_base import ObservedHolidayBase, SAT_SUN_TO_NEXT_WORKDAY
 
@@ -24,8 +24,8 @@ class Uzbekistan(ObservedHolidayBase, InternationalHolidays, IslamicHolidays, St
 
     References:
         * <https://en.wikipedia.org/wiki/Public_holidays_in_Uzbekistan>
-        * [Labor Code 21.12.1995](https://lex.uz/docs/-142859)
-        * [Labor Code 28.10.2022](https://lex.uz/docs/-6257288)
+        * [Labor Code 21.12.1995](https://web.archive.org/web/20250422170827/https://lex.uz/docs/-142859)
+        * [Labor Code 28.10.2022](https://web.archive.org/web/20250424164306/https://lex.uz/docs/-6257288)
     """
 
     country = "UZ"
@@ -39,7 +39,7 @@ class Uzbekistan(ObservedHolidayBase, InternationalHolidays, IslamicHolidays, St
     supported_languages = ("en_US", "uk", "uz")
     start_year = 1992
 
-    def __init__(self, islamic_show_estimated: bool = True, *args, **kwargs):
+    def __init__(self, *args, islamic_show_estimated: bool = True, **kwargs):
         """
         Args:
             islamic_show_estimated:
@@ -55,7 +55,7 @@ class Uzbekistan(ObservedHolidayBase, InternationalHolidays, IslamicHolidays, St
         super().__init__(*args, **kwargs)
 
     def _is_observed(self, dt: date) -> bool:
-        # Commencement of the new Labor Code
+        # Commencement of the new Labor Code.
         return dt >= date(2023, APR, 30)
 
     def _populate_public_holidays(self):
@@ -113,51 +113,39 @@ class UZB(Uzbekistan):
 
 
 class UzbekistanIslamicHolidays(_CustomIslamicHolidays):
+    EID_AL_ADHA_DATES_CONFIRMED_YEARS = (2006, 2025)
     EID_AL_ADHA_DATES = {
         2006: ((JAN, 10), (DEC, 30)),
         2007: (DEC, 19),
-        2008: (DEC, 8),
-        2009: (NOV, 27),
-        2010: (NOV, 16),
-        2011: (NOV, 6),
-        2012: (OCT, 26),
-        2013: (OCT, 15),
-        2014: (OCT, 4),
         2015: (SEP, 24),
         2016: (SEP, 12),
-        2017: (SEP, 1),
-        2018: (AUG, 21),
-        2019: (AUG, 11),
-        2020: (JUL, 31),
-        2021: (JUL, 20),
-        2022: (JUL, 9),
-        2023: (JUN, 28),
     }
 
+    EID_AL_FITR_DATES_CONFIRMED_YEARS = (2006, 2025)
     EID_AL_FITR_DATES = {
-        2006: (OCT, 23),
-        2007: (OCT, 13),
-        2008: (OCT, 1),
         2009: (SEP, 21),
-        2010: (SEP, 10),
         2011: (AUG, 31),
-        2012: (AUG, 19),
         2013: (AUG, 9),
-        2014: (JUL, 28),
         2015: (JUL, 18),
-        2016: (JUL, 6),
         2017: (JUN, 26),
-        2018: (JUN, 15),
         2019: (JUN, 5),
-        2020: (MAY, 24),
-        2021: (MAY, 13),
-        2022: (MAY, 2),
-        2023: (APR, 21),
-        2024: (APR, 10),
     }
 
 
 class UzbekistanStaticHolidays:
+    """Uzbekistan special holidays.
+
+    References:
+        * [2018](https://web.archive.org/web/20250610012705/https://lex.uz/ru/docs/3479237)
+        * [2019](https://web.archive.org/web/20250521124231/https://lex.uz/docs/-4054698)
+        * [2020](https://web.archive.org/web/20250522053834/https://lex.uz/docs/-4595638)
+        * [2021](https://web.archive.org/web/20250522053822/https://lex.uz/docs/-5137156)
+        * [2022](https://web.archive.org/web/20250522053831/https://lex.uz/docs/-5784917)
+        * [2023](https://web.archive.org/web/20250522053822/https://lex.uz/docs/-6324664)
+        * [2024](https://web.archive.org/web/20250522053835/https://lex.uz/docs/-6704048)
+        * [2025](https://web.archive.org/web/20250422135040/https://lex.uz/docs/-7275687)
+    """
+
     # Date format (see strftime() Format Codes)
     substituted_date_format = tr("%d/%m %Y")
     # Day off (substituted from %s).
@@ -171,7 +159,7 @@ class UzbekistanStaticHolidays:
             (JAN, 3, JAN, 6),
             (MAR, 19, MAR, 17),
             (MAR, 22, MAR, 24),
-            (MAR, 30, additional_day_off),
+            (MAR, 20, additional_day_off),
             (AUG, 23, AUG, 25),
             (AUG, 24, AUG, 26),
             (AUG, 31, additional_day_off),
@@ -232,4 +220,5 @@ class UzbekistanStaticHolidays:
             (DEC, 30, DEC, 14),
             (DEC, 31, additional_day_off),
         ),
+        2025: (JAN, 2, JAN, 4),
     }
