@@ -10,6 +10,7 @@
 #  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
+from datetime import date
 from gettext import gettext as tr
 
 from holidays.calendars import _CustomIslamicHolidays
@@ -45,6 +46,7 @@ class Yemen(ObservedHolidayBase, InternationalHolidays, IslamicHolidays):
     start_year = 1991
     supported_categories = (PUBLIC, SCHOOL, WORKDAY)
     supported_languages = ("ar", "en_US")
+    weekend = {FRI, SAT}
 
     def __init__(self, *args, islamic_show_estimated: bool = True, **kwargs):
         """
@@ -60,12 +62,13 @@ class Yemen(ObservedHolidayBase, InternationalHolidays, IslamicHolidays):
         kwargs.setdefault("observed_rule", FRI_TO_NEXT_WORKDAY)
         super().__init__(*args, **kwargs)
 
+    def _get_weekend(self, dt: date) -> set[int]:
+        # Yemen switches from THU-FRI to FRI-SAT on Aug 15, 2013.
+        return {FRI, SAT} if dt >= date(2013, AUG, 15) else {THU, FRI}
+
     def _populate_public_holidays(self):
         dts_observed = set()
 
-        # Yemen switches from THU-FRI to FRI-SAT on Aug 15, 2013
-        self.weekend = {THU, FRI} if self._year <= 2012 else {FRI, SAT}
-
         # Hijri New Year.
         dts_observed.update(self._add_islamic_new_year_day(tr("عيد رأس السنة الهجرية")))
 
