@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -13,8 +13,8 @@
 from datetime import date
 from typing import Optional
 
-from holidays.calendars import _ChineseLunisolar
-from holidays.calendars.gregorian import APR, DEC
+from holidays.calendars.chinese import _ChineseLunisolar, CHINESE_CALENDAR
+from holidays.calendars.gregorian import APR
 from holidays.groups.eastern import EasternCalendarHolidays
 
 
@@ -23,8 +23,10 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
     Chinese lunisolar calendar holidays.
     """
 
-    def __init__(self, cls=None, show_estimated=False) -> None:
-        self._chinese_calendar = cls() if cls else _ChineseLunisolar()
+    def __init__(self, cls=None, *, show_estimated=False, calendar=CHINESE_CALENDAR) -> None:
+        self._chinese_calendar = (
+            cls(calendar=calendar) if cls else _ChineseLunisolar(calendar=calendar)
+        )
         self._chinese_calendar_show_estimated = show_estimated
 
     @property
@@ -77,20 +79,8 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
     def _dongzhi_festival(self):
         """
         Return Dongzhi Festival (Chinese Winter Solstice) date.
-
-        This approximation is reliable for 1952-2099 years.
         """
-        #
-        if (
-            (self._year % 4 == 0 and self._year >= 1988)
-            or (self._year % 4 == 1 and self._year >= 2021)
-            or (self._year % 4 == 2 and self._year >= 2058)
-            or (self._year % 4 == 3 and self._year >= 2091)
-        ):
-            day = 21
-        else:
-            day = 22
-        return date(self._year, DEC, day)
+        return self._chinese_calendar.winter_solstice_date(self._year)[0]
 
     def _add_chinese_calendar_holiday(
         self, name: str, dt_estimated: tuple[Optional[date], bool], days_delta: int = 0
@@ -102,7 +92,10 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
         is an estimation.
         """
         return self._add_eastern_calendar_holiday(
-            name, dt_estimated, self._chinese_calendar_show_estimated, days_delta
+            name,
+            dt_estimated,
+            show_estimated=self._chinese_calendar_show_estimated,
+            days_delta=days_delta,
         )
 
     def _add_chinese_birthday_of_buddha(self, name) -> Optional[date]:
@@ -113,18 +106,29 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
         Birthday of the Buddha is a Buddhist festival that is celebrated in
         most of East Asia and South Asia commemorating the birth of Gautama
         Buddha, who was the founder of Buddhism.
-        https://en.wikipedia.org/wiki/Buddha%27s_Birthday
+        https://en.wikipedia.org/wiki/Buddha's_Birthday
         """
         return self._add_chinese_calendar_holiday(
             name, self._chinese_calendar.buddha_birthday_date(self._year)
         )
 
+    def _add_chinese_day_before_new_years_eve(self, name) -> Optional[date]:
+        """
+        Add day before Chinese New Year's Eve (second to last day of 12th lunar month).
+
+        Chinese New Year's Eve is the day before the Chinese New Year.
+        https://en.wikipedia.org/wiki/Chinese_New_Year's_Eve
+        """
+        return self._add_chinese_calendar_holiday(
+            name, self._chinese_calendar.lunar_new_year_date(self._year), days_delta=-2
+        )
+
     def _add_chinese_new_years_eve(self, name) -> Optional[date]:
         """
         Add Chinese New Year's Eve (last day of 12th lunar month).
 
         Chinese New Year's Eve is the day before the Chinese New Year.
-        https://en.wikipedia.org/wiki/Chinese_New_Year%27s_Eve
+        https://en.wikipedia.org/wiki/Chinese_New_Year's_Eve
         """
         return self._add_chinese_calendar_holiday(
             name, self._chinese_calendar.lunar_new_year_date(self._year), days_delta=-1
@@ -182,6 +186,18 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
             name, self._chinese_calendar.lunar_new_year_date(self._year), days_delta=+4
         )
 
+    def _add_daeboreum_day(self, name) -> Optional[date]:
+        """
+        Add Daeboreum Day (15th day of 1st lunar month).
+
+        Daeboreum is a Korean holiday that celebrates the first full moon
+        of the new year of the lunar Korean calendar.
+        https://en.wikipedia.org/wiki/Daeboreum
+        """
+        return self._add_chinese_calendar_holiday(
+            name, self._chinese_calendar.lunar_new_year_date(self._year), days_delta=+14
+        )
+
     def _add_dongzhi_festival(self, name) -> Optional[date]:
         """
         Add Dongzhi Festival (Chinese Winter Solstice).
@@ -193,6 +209,19 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
         """
         return self._add_holiday(name, self._dongzhi_festival)
 
+    def _add_hanshi_festival(self, name) -> Optional[date]:
+        """
+        Add Hanshi Festival (105 days after Winter Solstice).
+
+        The Cold Food or Hanshi Festival is a traditional Chinese holiday. Its name
+        derives from the tradition of avoiding the lighting of any kind of fire,
+        even for the preparation of food.
+        https://en.wikipedia.org/wiki/Cold_Food_Festival
+        """
+        return self._add_chinese_calendar_holiday(
+            name, self._chinese_calendar.winter_solstice_date(self._year - 1), days_delta=+105
+        )
+
     def _add_qingming_festival(self, name) -> date:
         """
         Add Qingming Festival (15th day after the Spring Equinox).
@@ -233,7 +262,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
 
         Vietnamese festival held annually from the 8th to the 11th day of the
         3rd lunar month in honour of the Hùng Kings.
-        https://en.wikipedia.org/wiki/H%C3%B9ng_Kings%27_Festival
+        https://en.wikipedia.org/wiki/Hùng_Kings'_Festival
         """
         return self._add_chinese_calendar_holiday(
             name, self._chinese_calendar.hung_kings_date(self._year)
