@@ -10,6 +10,7 @@
 #  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
+from collections.abc import Iterable
 from datetime import date
 from typing import Optional
 
@@ -25,6 +26,7 @@ class EasternCalendarHolidays:
         self,
         name: str,
         dt_estimated: tuple[Optional[date], bool],
+        *,
         show_estimated: bool = True,
         days_delta: int = 0,
     ) -> Optional[date]:
@@ -33,15 +35,13 @@ class EasternCalendarHolidays:
 
         Adds customizable estimation label to holiday name if holiday date is an estimation.
         """
-        estimated_label = getattr(self, "estimated_label", "%s")
         dt, is_estimated = dt_estimated
-
         if days_delta and dt:
             dt = _timedelta(dt, days_delta)
 
         return (
             self._add_holiday(
-                self.tr(estimated_label) % self.tr(name)
+                self.tr(self.estimated_label) % self.tr(name)
                 if is_estimated and show_estimated
                 else name,
                 dt,
@@ -49,3 +49,27 @@ class EasternCalendarHolidays:
             if dt
             else None
         )
+
+    def _add_eastern_calendar_holiday_set(
+        self,
+        name: str,
+        dts_estimated: Iterable[tuple[date, bool]],
+        *,
+        show_estimated: bool = True,
+        days_delta: int = 0,
+    ) -> set[date]:
+        """
+        Add Eastern (Buddhist, Chinese, Hindu, Islamic, Mongolian) calendar holidays.
+
+        Adds customizable estimation label to holiday name if holiday date is an estimation.
+        """
+
+        return {
+            dt
+            for dt_estimated in dts_estimated
+            if (
+                dt := self._add_eastern_calendar_holiday(
+                    name, dt_estimated, show_estimated=show_estimated, days_delta=days_delta
+                )
+            )
+        }
