@@ -808,7 +808,7 @@ class HolidayBase(dict[date, str]):
         self[dt] = self.tr(name)
         return dt
 
-    def _add_special_holidays(self, mapping_names, observed=False):
+    def _add_special_holidays(self, mapping_names, *, observed=False):
         """Add special holidays."""
         for mapping_name in mapping_names:
             for data in _normalize_tuple(getattr(self, mapping_name, {}).get(self._year, ())):
@@ -841,6 +841,9 @@ class HolidayBase(dict[date, str]):
         dt = dt if isinstance(dt, date) else date(self._year, *dt)
         return dt.weekday() == weekday
 
+    def _get_weekend(self, dt: date) -> set[int]:
+        return self.weekend
+
     def _is_monday(self, *args) -> bool:
         return self._check_weekday(MON, *args)
 
@@ -862,14 +865,21 @@ class HolidayBase(dict[date, str]):
     def _is_sunday(self, *args) -> bool:
         return self._check_weekday(SUN, *args)
 
-    def _is_weekend(self, *args):
+    def _is_weekday(self, *args) -> bool:
+        """
+        Returns True if date's week day is not a weekend day.
+        Returns False otherwise.
+        """
+        return not self._is_weekend(*args)
+
+    def _is_weekend(self, *args) -> bool:
         """
         Returns True if date's week day is a weekend day.
         Returns False otherwise.
         """
         dt = args if len(args) > 1 else args[0]
         dt = dt if isinstance(dt, date) else date(self._year, *dt)
-        return dt.weekday() in self.weekend
+        return dt.weekday() in self._get_weekend(dt)
 
     def _populate(self, year: int) -> None:
         """This is a private method that populates (generates and adds) holidays
@@ -1145,9 +1155,7 @@ class HolidayBase(dict[date, str]):
         Returns:
             True if the date's week day is a weekend day, False otherwise.
         """
-        # To prioritize performance we avoid reusing the internal
-        # `HolidayBase._is_weekend` method and perform the check directly instead.
-        return self.__keytransform__(key).weekday() in self.weekend
+        return self._is_weekend(self.__keytransform__(key))
 
     def is_working_day(self, key: DateLike) -> bool:
         """Check if the given date is considered a working day.
@@ -1360,11 +1368,12 @@ class HolidaySum(HolidayBase):
             else:
                 self.holidays.append(operand)
 
-        kwargs: dict[str, Any] = {}
         # Join years, expand and observed.
-        kwargs["years"] = h1.years | h2.years
-        kwargs["expand"] = h1.expand or h2.expand
-        kwargs["observed"] = h1.observed or h2.observed
+        kwargs: dict[str, Any] = {
+            "expand": h1.expand or h2.expand,
+            "observed": h1.observed or h2.observed,
+            "years": h1.years | h2.years,
+        }
         # Join country and subdivisions data.
         # TODO: this way makes no sense: joining Italy Catania (IT, CA) with
         # USA Mississippi (US, MS) and USA Michigan (US, MI) yields
@@ -1373,25 +1382,16 @@ class HolidaySum(HolidayBase):
         # and Milano, or ... you get the picture.
         # Same goes when countries and markets are being mixed (working, yet
         # still nonsensical).
+        value: Optional[Union[str, list[str]]]
         for attr in ("country", "market", "subdiv"):
-            if (
-                getattr(h1, attr, None)
-                and getattr(h2, attr, None)
-                and getattr(h1, attr) != getattr(h2, attr)
-            ):
-                a1 = (
-                    getattr(h1, attr)
-                    if isinstance(getattr(h1, attr), list)
-                    else [getattr(h1, attr)]
-                )
-                a2 = (
-                    getattr(h2, attr)
-                    if isinstance(getattr(h2, attr), list)
-                    else [getattr(h2, attr)]
-                )
+            a1 = getattr(h1, attr, None)
+            a2 = getattr(h2, attr, None)
+            if a1 and a2 and a1 != a2:
+                a1 = a1 if isinstance(a1, list) else [a1]
+                a2 = a2 if isinstance(a2, list) else [a2]
                 value = a1 + a2
             else:
-                value = getattr(h1, attr, None) or getattr(h2, attr, None)
+                value = a1 or a2
 
             if attr == "subdiv":
                 kwargs[attr] = value
