@@ -12,9 +12,10 @@
 
 import re
 import uuid
-from datetime import date, datetime, timedelta, timezone
+from datetime import date, datetime, timezone
 from typing import Union
 
+from holidays.calendars.gregorian import _timedelta
 from holidays.holiday_base import HolidayBase
 from holidays.version import __version__
 
@@ -185,16 +186,17 @@ class ICalExporter:
 
         sorted_dates = sorted(self.holidays.keys())
         # Merged continuous holiday with the same name and use `DURATION` instead.
+        n = len(sorted_dates)
         i = 0
-        while i < len(sorted_dates):
+        while i < n:
             dt = sorted_dates[i]
             names = self.holidays.get_list(dt)
 
             for name in names:
                 days = 1
                 while (
-                    i + days < len(sorted_dates)
-                    and sorted_dates[i + days] == sorted_dates[i] + timedelta(days=days)
+                    i + days < n
+                    and sorted_dates[i + days] == _timedelta(sorted_dates[i], days)
                     and name in self.holidays.get_list(sorted_dates[i + days])
                 ):
                     days += 1
