@@ -28,6 +28,7 @@ COUNTRIES: RegistryDict = {
     "andorra": ("Andorra", "AD", "AND"),
     "angola": ("Angola", "AO", "AGO"),
     "anguilla": ("Anguilla", "AI", "AIA"),
+    "antarctica": ("Antarctica", "AQ", "ATA"),
     "antigua_and_barbuda": ("AntiguaAndBarbuda", "AG", "ATG"),
     "argentina": ("Argentina", "AR", "ARG"),
     "armenia": ("Armenia", "AM", "ARM"),
@@ -49,7 +50,9 @@ COUNTRIES: RegistryDict = {
     "bonaire_sint_eustatius_and_saba": ("BonaireSintEustatiusAndSaba", "BQ", "BES"),
     "bosnia_and_herzegovina": ("BosniaAndHerzegovina", "BA", "BIH"),
     "botswana": ("Botswana", "BW", "BWA"),
+    "bouvet_island": ("BouvetIsland", "BV", "BVT"),
     "brazil": ("Brazil", "BR", "BRA"),
+    "british_indian_ocean_territory": ("BritishIndianOceanTerritory", "IO", "IOT"),
     "british_virgin_islands": ("BritishVirginIslands", "VG", "VGB"),
     "brunei": ("Brunei", "BN", "BRN"),
     "bulgaria": ("Bulgaria", "BG", "BLG"),
@@ -115,6 +118,7 @@ COUNTRIES: RegistryDict = {
     "guinea_bissau": ("GuineaBissau", "GW", "GNB"),
     "guyana": ("Guyana", "GY", "GUY"),
     "haiti": ("Haiti", "HT", "HTI"),
+    "heard_island_and_mcdonald_islands": ("HeardIslandAndMcDonaldIslands", "HM", "HMD"),
     "honduras": ("Honduras", "HN", "HND"),
     "hongkong": ("HongKong", "HK", "HKG"),
     "hungary": ("Hungary", "HU", "HUN"),
@@ -166,6 +170,7 @@ COUNTRIES: RegistryDict = {
     "montserrat": ("Montserrat", "MS", "MSR"),
     "morocco": ("Morocco", "MA", "MOR"),
     "mozambique": ("Mozambique", "MZ", "MOZ"),
+    "myanmar": ("Myanmar", "MM", "MMR"),
     "namibia": ("Namibia", "NA", "NAM"),
     "nauru": ("Nauru", "NR", "NRU"),
     "nepal": ("Nepal", "NP", "NPL"),
@@ -177,6 +182,7 @@ COUNTRIES: RegistryDict = {
     "nigeria": ("Nigeria", "NG", "NGA"),
     "niue": ("Niue", "NU", "NIU"),
     "norfolk_island": ("NorfolkIsland", "NF", "NFK"),
+    "north_korea": ("NorthKorea", "KP", "PRK"),
     "north_macedonia": ("NorthMacedonia", "MK", "MKD"),
     "northern_mariana_islands": ("NorthernMarianaIslands", "MP", "MNP", "HolidaysMP"),
     "norway": ("Norway", "NO", "NOR"),
@@ -199,6 +205,11 @@ COUNTRIES: RegistryDict = {
     "russia": ("Russia", "RU", "RUS"),
     "rwanda": ("Rwanda", "RW", "RWA"),
     "saint_barthelemy": ("SaintBarthelemy", "BL", "BLM", "HolidaysBL"),
+    "saint_helena_ascension_and_tristan_da_cunha": (
+        "SaintHelenaAscensionAndTristanDaCunha",
+        "SH",
+        "SHN",
+    ),
     "saint_kitts_and_nevis": ("SaintKittsAndNevis", "KN", "KNA"),
     "saint_lucia": ("SaintLucia", "LC", "LCA"),
     "saint_martin": ("SaintMartin", "MF", "MAF", "HolidaysMF"),
@@ -228,6 +239,7 @@ COUNTRIES: RegistryDict = {
     "south_sudan": ("SouthSudan", "SS", "SSD"),
     "spain": ("Spain", "ES", "ESP"),
     "sri_lanka": ("SriLanka", "LK", "LKA"),
+    "sudan": ("Sudan", "SD", "SDN"),
     "suriname": ("Suriname", "SR", "SUR"),
     "svalbard_and_jan_mayen": ("SvalbardAndJanMayen", "SJ", "SJM", "HolidaysSJ"),
     "sweden": ("Sweden", "SE", "SWE"),
@@ -266,6 +278,7 @@ COUNTRIES: RegistryDict = {
     "venezuela": ("Venezuela", "VE", "VEN"),
     "vietnam": ("Vietnam", "VN", "VNM"),
     "wallis_and_futuna": ("WallisAndFutuna", "WF", "WLF", "HolidaysWF"),
+    "western_sahara": ("WesternSahara", "EH", "ESH"),
     "yemen": ("Yemen", "YE", "YEM"),
     "zambia": ("Zambia", "ZM", "ZMB"),
     "zimbabwe": ("Zimbabwe", "ZW", "ZWE"),
@@ -339,6 +352,7 @@ class EntityLoader:
     @staticmethod
     def _get_entity_codes(
         container: RegistryDict,
+        *,
         include_aliases: bool = True,
         max_code_length: int = 3,
         min_code_length: int = 2,
