@@ -44,8 +44,9 @@ class TestAS(CommonCountryTests, TestCase):
             ("2022-03-17", "Saint Patrick's Day"),
             ("2022-04-17", "American Samoa Flag Day"),
             ("2022-04-18", "American Samoa Flag Day (observed)"),
+            ("2022-05-08", "Mother's Day"),
             ("2022-05-30", "Memorial Day"),
-            ("2022-06-19", "Juneteenth National Independence Day"),
+            ("2022-06-19", "Father's Day; Juneteenth National Independence Day"),
             ("2022-06-20", "Juneteenth National Independence Day (observed)"),
             ("2022-07-04", "Independence Day"),
             ("2022-07-15", "Manu'a Islands Cession Day (observed)"),
@@ -70,8 +71,9 @@ class TestAS(CommonCountryTests, TestCase):
             ("2022-03-17", "วันนักบุญแพทริก"),
             ("2022-04-17", "วันธงชาติอเมริกันซามัว"),
             ("2022-04-18", "ชดเชยวันธงชาติอเมริกันซามัว"),
+            ("2022-05-08", "วันแม่"),
             ("2022-05-30", "วันรำลึก"),
-            ("2022-06-19", "วันประกาศอิสรภาพแห่งชาติจูนทีนท์"),
+            ("2022-06-19", "วันประกาศอิสรภาพแห่งชาติจูนทีนท์; วันพ่อ"),
             ("2022-06-20", "ชดเชยวันประกาศอิสรภาพแห่งชาติจูนทีนท์"),
             ("2022-07-04", "วันประกาศอิสรภาพ"),
             ("2022-07-15", "ชดเชยวันส่งมอบหมู่เกาะมานูอา"),
