@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -20,15 +20,17 @@ from tests.common import CommonCountryTests
 class TestCuracao(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        super().setUpClass(Curacao, years=range(1954, 2050))
+        super().setUpClass(Curacao, years=range(1955, 2050))
+        cls.halfday_holidays = Curacao(categories=HALF_DAY, years=range(2010, 2050))
 
     def test_country_aliases(self):
         self.assertAliases(Curacao, CW, CUW)
 
     def test_no_holidays(self):
-        self.assertNoHolidays(Curacao(categories=(HALF_DAY, PUBLIC), years=1953))
+        self.assertNoHolidays(Curacao(categories=PUBLIC, years=1954))
+        self.assertNoHolidays(Curacao(categories=HALF_DAY, years=2009))
 
-    def test_2016(self):
+    def test_2016_public(self):
         self.assertHolidays(
             Curacao(years=2016),
             ("2016-01-01", "Aña Nobo"),
@@ -51,6 +53,60 @@ class TestCuracao(CommonCountryTests, TestCase):
             ("2016-12-31", "Vispu di Aña Nobo"),
         )
 
+    def test_new_years_day(self):
+        self.assertHolidayName("Aña Nobo", (f"{year}-01-01" for year in range(1955, 2050)))
+
+    def test_carnival_monday(self):
+        name = "Dialuna despues di Carnaval Grandi"
+        self.assertHolidayName(
+            name,
+            "2021-02-15",
+            "2022-02-28",
+            "2023-02-20",
+            "2024-02-12",
+            "2025-03-03",
+        )
+        self.assertHolidayName(name, range(1955, 2050))
+
+    def test_good_friday(self):
+        name = "Bièrnèsantu"
+        self.assertHolidayName(
+            name,
+            "2020-04-10",
+            "2021-04-02",
+            "2022-04-15",
+            "2023-04-07",
+            "2024-03-29",
+            "2025-04-18",
+        )
+        self.assertHolidayName(name, range(1955, 2050))
+
+    def test_easter_sunday(self):
+        name = "Pasku di Resurekshon"
+        self.assertHolidayName(
+            name,
+            "2020-04-12",
+            "2021-04-04",
+            "2022-04-17",
+            "2023-04-09",
+            "2024-03-31",
+            "2025-04-20",
+        )
+        self.assertHolidayName(name, range(1955, 2050))
+
+    def test_easter_monday(self):
+        name = "Di dos dia di Pasku di Resurekshon"
+        self.assertHolidayName(
+            name,
+            "2020-04-13",
+            "2021-04-05",
+            "2022-04-18",
+            "2023-04-10",
+            "2024-04-01",
+            "2025-04-21",
+        )
+        self.assertHolidayName(name, range(1955, 2050))
+
     def test_queens_day(self):
         name = "Dia di la Reina"
         self.assertHolidayName(
@@ -66,7 +122,9 @@ class TestCuracao(CommonCountryTests, TestCase):
             "2006-04-29",
             "2013-04-30",
         )
-        self.assertNoHoliday(
+        self.assertHolidayName(name, range(1955, 2014))
+        self.assertNoHolidayName(
+            name,
             "1961-04-30",
             "1967-04-30",
             "1972-04-30",
@@ -76,11 +134,10 @@ class TestCuracao(CommonCountryTests, TestCase):
             "2000-04-30",
             "2006-04-30",
         )
-        self.assertNoHolidayName(name, 2014)
+        self.assertNoHolidayName(name, range(2014, 2050))
 
     def test_king_day(self):
         name = "Dia di Rey"
-        self.assertNoHolidayName(name, 2013)
         self.assertHolidayName(
             name,
             "2016-04-27",
@@ -96,16 +153,20 @@ class TestCuracao(CommonCountryTests, TestCase):
             "2031-04-26",
             "2036-04-26",
         )
-        self.assertNoHoliday(
+        self.assertHolidayName(name, range(2014, 2050))
+        self.assertNoHolidayName(
+            name,
             "2014-04-27",
             "2025-04-27",
             "2031-04-27",
             "2036-04-27",
         )
+        self.assertNoHolidayName(name, range(1955, 2014))
 
     def test_labor_day(self):
+        name = "Dia di Obrero"
         self.assertHolidayName(
-            "Dia di Obrero",
+            name,
             "2016-05-02",
             "2017-05-01",
             "2018-05-01",
@@ -115,21 +176,64 @@ class TestCuracao(CommonCountryTests, TestCase):
             "2022-05-02",
             "2023-05-01",
         )
-        self.assertNoHoliday(
+        self.assertHolidayName(name, range(1955, 2050))
+        self.assertNoHolidayName(
             "2011-05-01",
             "2016-05-01",
             "2022-05-01",
         )
 
-    def test_anthem_and_flag_day(self):
+    def test_ascension_day(self):
+        name = "Dia di Asenshon"
+        self.assertHolidayName(
+            name,
+            "2020-05-21",
+            "2021-05-13",
+            "2022-05-26",
+            "2023-05-18",
+            "2024-05-09",
+            "2025-05-29",
+        )
+        self.assertHolidayName(name, range(1955, 2050))
+
+    def test_whit_sunday(self):
+        name = "Domingo di Pentekòstès"
+        self.assertHolidayName(
+            name,
+            "2005-05-15",
+            "2006-06-04",
+            "2007-05-27",
+            "2008-05-11",
+            "2009-05-31",
+        )
+        self.assertHolidayName(name, range(1955, 2010))
+        self.assertNoHolidayName(name, range(2010, 2050))
+
+    def test_national_anthem_and_flag_day(self):
         name = "Dia di Himno i Bandera"
-        self.assertNoHolidayName(name, range(1954, 1983))
         self.assertHolidayName(name, (f"{year}-07-02" for year in range(1984, 2050)))
+        self.assertNoHolidayName(name, range(1955, 1984))
 
     def test_curacao_day(self):
         name = "Dia di Pais Kòrsou"
-        self.assertNoHolidayName(name, range(1954, 2009))
         self.assertHolidayName(name, (f"{year}-10-10" for year in range(2010, 2050)))
+        self.assertNoHolidayName(name, range(1955, 2010))
+
+    def test_christmas(self):
+        self.assertHolidayName(
+            "Pasku di Nasementu", (f"{year}-12-25" for year in range(1955, 2050))
+        )
+        self.assertHolidayName(
+            "Di dos dia di Pasku di Nasementu", (f"{year}-12-26" for year in range(1955, 2050))
+        )
+
+    def test_new_years_eve(self):
+        name = "Vispu di Aña Nobo"
+        self.assertHolidayName(
+            name, self.halfday_holidays, (f"{year}-12-31" for year in range(2010, 2050))
+        )
+        self.assertNoHolidayName(name, self.halfday_holidays, range(1955, 2010))
+        self.assertNoHolidayName(name)
 
     def test_l10n_default(self):
         self.assertLocalizedHolidays(
@@ -179,7 +283,7 @@ class TestCuracao(CommonCountryTests, TestCase):
             ("2023-05-18", "Hemelvaartsdag"),
             ("2023-07-02", "Nationale vlag en volkslied"),
             ("2023-10-10", "Dag van Land Curaçao"),
-            ("2023-12-25", "Kerst"),
+            ("2023-12-25", "Eerste Kerstdag"),
             ("2023-12-26", "Tweede kerstdag"),
             ("2023-12-31", "Oudejaarsavond"),
         )
