@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -65,17 +65,17 @@ class TestDjibouti(CommonCountryTests, TestCase):
         self.assertLocalizedHolidays(
             "ar",
             ("2022-01-01", "يوم السنة الجديدة"),
-            ("2022-02-28", "(تقدير) الإسراء والمعراج"),
+            ("2022-02-28", "الإسراء والمعراج (المقدرة)"),
             ("2022-05-01", "عيد العمال"),
-            ("2022-05-02", "(تقدير) عيد الفطر"),
-            ("2022-05-03", "(تقدير) عطلة عيد الفطر"),
+            ("2022-05-02", "عيد الفطر (المقدرة)"),
+            ("2022-05-03", "عطلة عيد الفطر (المقدرة)"),
             ("2022-06-27", "عيد الإستقلال"),
             ("2022-06-28", "عطلة عيد الاستقلال"),
-            ("2022-07-08", "(تقدير) يوم عرفة"),
-            ("2022-07-09", "(تقدير) عيد الأضحى"),
-            ("2022-07-10", "(تقدير) عطلة عيد الأضحى"),
-            ("2022-07-30", "(تقدير) رأس السنة الهجرية"),
-            ("2022-10-08", "(تقدير) عيد المولد النبوي"),
+            ("2022-07-08", "يوم عرفة (المقدرة)"),
+            ("2022-07-09", "عيد الأضحى (المقدرة)"),
+            ("2022-07-10", "عطلة عيد الأضحى (المقدرة)"),
+            ("2022-07-30", "رأس السنة الهجرية (المقدرة)"),
+            ("2022-10-08", "عيد المولد النبوي (المقدرة)"),
             ("2022-12-25", "عيد الميلاد المجيد"),
         )
 
