@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -13,10 +13,10 @@
 from unittest import TestCase
 
 from holidays.countries.hungary import Hungary, HU, HUN
-from tests.common import CommonCountryTests
+from tests.common import CommonCountryTests, WorkingDayTests
 
 
-class TestHungary(CommonCountryTests, TestCase):
+class TestHungary(CommonCountryTests, WorkingDayTests, TestCase):
     @classmethod
     def setUpClass(cls):
         super().setUpClass(Hungary, years=range(1945, 2050))
@@ -24,6 +24,181 @@ class TestHungary(CommonCountryTests, TestCase):
     def test_country_aliases(self):
         self.assertAliases(Hungary, HU, HUN)
 
+    def test_no_holidays(self):
+        self.assertNoHolidays(Hungary(years=1944))
+
+    def test_substituted_holidays(self):
+        self.assertHoliday(
+            "1991-08-19",
+            "1992-08-21",
+            "1992-12-24",
+            "1993-12-24",
+            "1994-03-14",
+            "1997-05-02",
+            "1997-10-24",
+            "1997-12-24",
+            "1998-01-02",
+            "1998-08-21",
+            "1998-12-24",
+            "1999-12-24",
+            "2001-03-16",
+            "2001-04-30",
+            "2001-10-22",
+            "2001-11-02",
+            "2001-12-24",
+            "2001-12-31",
+            "2002-08-19",
+            "2002-12-24",
+            "2003-05-02",
+            "2003-10-24",
+            "2003-12-24",
+            "2004-01-02",
+            "2004-12-24",
+            "2005-03-14",
+            "2005-10-31",
+            "2007-03-16",
+            "2007-04-30",
+            "2007-10-22",
+            "2007-11-02",
+            "2007-12-24",
+            "2007-12-31",
+            "2008-05-02",
+            "2008-10-24",
+            "2008-12-24",
+            "2009-01-02",
+            "2009-08-21",
+            "2009-12-24",
+            "2010-12-24",
+            "2011-03-14",
+            "2011-10-31",
+            "2012-03-16",
+            "2012-04-30",
+            "2012-10-22",
+            "2012-11-02",
+            "2012-12-24",
+            "2012-12-31",
+            "2013-08-19",
+            "2013-12-24",
+            "2013-12-27",
+            "2014-05-02",
+            "2014-10-24",
+            "2014-12-24",
+            "2015-01-02",
+            "2015-08-21",
+            "2015-12-24",
+            "2016-03-14",
+            "2016-10-31",
+            "2018-03-16",
+            "2018-04-30",
+            "2018-10-22",
+            "2018-11-02",
+            "2018-12-24",
+            "2018-12-31",
+            "2019-08-19",
+            "2019-12-24",
+            "2019-12-27",
+            "2020-08-21",
+            "2020-12-24",
+            "2021-12-24",
+            "2022-03-14",
+            "2022-10-31",
+            "2024-08-19",
+            "2024-12-24",
+            "2024-12-27",
+            "2025-05-02",
+            "2025-10-24",
+            "2025-12-24",
+            "2026-01-02",
+            "2026-08-21",
+            "2026-12-24",
+        )
+
+    def test_workdays(self):
+        self.assertWorkingDay(
+            "1991-08-17",
+            "1992-08-29",
+            "1992-12-19",
+            "1993-12-18",
+            "1994-03-12",
+            "1997-04-26",
+            "1997-10-18",
+            "1997-12-20",
+            "1998-01-10",
+            "1998-08-15",
+            "1998-12-19",
+            "1999-12-18",
+            "2001-03-10",
+            "2001-04-28",
+            "2001-10-20",
+            "2001-10-27",
+            "2001-12-22",
+            "2001-12-29",
+            "2002-08-10",
+            "2002-12-28",
+            "2003-04-26",
+            "2003-10-18",
+            "2003-12-13",
+            "2004-01-10",
+            "2004-12-18",
+            "2005-03-19",
+            "2005-11-05",
+            "2007-03-10",
+            "2007-04-21",
+            "2007-10-20",
+            "2007-10-27",
+            "2007-12-22",
+            "2007-12-29",
+            "2008-04-26",
+            "2008-10-18",
+            "2008-12-20",
+            "2009-03-28",
+            "2009-08-29",
+            "2009-12-19",
+            "2010-12-11",
+            "2011-03-19",
+            "2011-11-05",
+            "2012-03-24",
+            "2012-04-21",
+            "2012-10-27",
+            "2012-11-10",
+            "2012-12-15",
+            "2012-12-01",
+            "2013-08-24",
+            "2013-12-07",
+            "2013-12-21",
+            "2014-05-10",
+            "2014-10-18",
+            "2014-12-13",
+            "2015-01-10",
+            "2015-08-08",
+            "2015-12-12",
+            "2016-03-05",
+            "2016-10-15",
+            "2018-03-10",
+            "2018-04-21",
+            "2018-10-13",
+            "2018-11-10",
+            "2018-12-01",
+            "2018-12-15",
+            "2019-08-10",
+            "2019-12-07",
+            "2019-12-14",
+            "2020-08-29",
+            "2020-12-12",
+            "2021-12-11",
+            "2022-03-26",
+            "2022-10-15",
+            "2024-08-03",
+            "2024-12-07",
+            "2024-12-14",
+            "2025-05-17",
+            "2025-10-18",
+            "2025-12-13",
+            "2026-01-10",
+            "2026-08-08",
+            "2026-12-12",
+        )
+
     def test_new_years_day(self):
         self.assertHolidayName("Újév", (f"{year}-01-01" for year in range(1945, 2050)))
 
@@ -48,6 +223,7 @@ class TestHungary(CommonCountryTests, TestCase):
             "2022-04-15",
             "2023-04-07",
         )
+        self.assertHolidayName(name, range(2017, 2050))
         self.assertNoHolidayName(name, range(1945, 2017))
 
     def test_easter(self):
@@ -182,51 +358,6 @@ class TestHungary(CommonCountryTests, TestCase):
         self.assertNoHoliday(f"{year}-11-07" for year in years_absent)
         self.assertNoHolidayName(name, years_absent)
 
-    def test_substituted(self):
-        dt = (
-            "2010-12-24",
-            "2011-03-14",
-            "2011-10-31",
-            "2012-03-16",
-            "2012-04-30",
-            "2012-10-22",
-            "2012-11-02",
-            "2012-12-24",
-            "2012-12-31",
-            "2013-08-19",
-            "2013-12-24",
-            "2013-12-27",
-            "2014-05-02",
-            "2014-10-24",
-            "2014-12-24",
-            "2015-01-02",
-            "2015-08-21",
-            "2015-12-24",
-            "2016-03-14",
-            "2016-10-31",
-            "2018-03-16",
-            "2018-04-30",
-            "2018-10-22",
-            "2018-11-02",
-            "2018-12-24",
-            "2018-12-31",
-            "2019-08-19",
-            "2019-12-24",
-            "2019-12-27",
-            "2020-08-21",
-            "2020-12-24",
-            "2021-12-24",
-            "2022-03-14",
-            "2022-10-31",
-            "2024-08-19",
-            "2024-12-24",
-            "2024-12-27",
-            "2025-05-02",
-            "2025-10-24",
-            "2025-12-24",
-        )
-        self.assertHoliday(dt)
-
     def test_2021(self):
         self.assertHolidays(
             Hungary(years=2021),
