@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -34,7 +34,7 @@ class TestIsrael(CommonCountryTests, TestCase):
 
     def test_independence_day(self):
         name = "יום העצמאות"
-        name_observed = f"(נצפה) {name}"
+        name_observed = f"{name} (נצפה)"
         common_dt = (
             "2000-05-10",
             "2002-04-17",
@@ -89,7 +89,7 @@ class TestIsrael(CommonCountryTests, TestCase):
 
     def test_memorial_day(self):
         name = "יום הזיכרון לחללי מערכות ישראל ונפגעי פעולות האיבה"
-        name_observed = f"(נצפה) {name}"
+        name_observed = f"{name} (נצפה)"
         common_dt = (
             "2000-05-09",
             "2002-04-16",
@@ -172,7 +172,7 @@ class TestIsrael(CommonCountryTests, TestCase):
 
     def test_tisha_bav(self):
         name = "תשעה באב"
-        name_observed = f"(נצפה) {name}"
+        name_observed = f"{name} (נצפה)"
         common_dt = (
             "2000-08-10",
             "2001-07-29",
@@ -219,7 +219,7 @@ class TestIsrael(CommonCountryTests, TestCase):
 
     def test_taanit_ester(self):
         name = "תענית אסתר"
-        name_observed = f"(נצפה) {name}"
+        name_observed = f"{name} (נצפה)"
         common_dt = (
             "2000-03-20",
             "2001-03-08",
@@ -274,7 +274,7 @@ class TestIsrael(CommonCountryTests, TestCase):
             Israel(years=2021),
             ("2021-03-28", "פסח"),
             ("2021-04-03", "שביעי של פסח"),
-            ("2021-04-15", "(נצפה) יום העצמאות"),
+            ("2021-04-15", "יום העצמאות (נצפה)"),
             ("2021-05-17", "שבועות"),
             ("2021-09-07", "ראש השנה"),
             ("2021-09-08", "ראש השנה"),
@@ -288,7 +288,7 @@ class TestIsrael(CommonCountryTests, TestCase):
             Israel(years=2022),
             ("2022-04-16", "פסח"),
             ("2022-04-22", "שביעי של פסח"),
-            ("2022-05-05", "(נצפה) יום העצמאות"),
+            ("2022-05-05", "יום העצמאות (נצפה)"),
             ("2022-06-05", "שבועות"),
             ("2022-09-26", "ראש השנה"),
             ("2022-09-27", "ראש השנה"),
@@ -320,7 +320,7 @@ class TestIsrael(CommonCountryTests, TestCase):
             ("2021-03-31", "חול המועד פסח"),
             ("2021-04-01", "חול המועד פסח"),
             ("2021-04-02", "חול המועד פסח"),
-            ("2021-04-14", "(נצפה) יום הזיכרון לחללי מערכות ישראל ונפגעי פעולות האיבה"),
+            ("2021-04-14", "יום הזיכרון לחללי מערכות ישראל ונפגעי פעולות האיבה (נצפה)"),
             ("2021-05-10", "יום ירושלים"),
             ("2021-07-18", "תשעה באב"),
             ("2021-09-22", "חול המועד סוכות"),
@@ -340,9 +340,9 @@ class TestIsrael(CommonCountryTests, TestCase):
             ("2022-04-19", "חול המועד פסח"),
             ("2022-04-20", "חול המועד פסח"),
             ("2022-04-21", "חול המועד פסח"),
-            ("2022-05-04", "(נצפה) יום הזיכרון לחללי מערכות ישראל ונפגעי פעולות האיבה"),
+            ("2022-05-04", "יום הזיכרון לחללי מערכות ישראל ונפגעי פעולות האיבה (נצפה)"),
             ("2022-05-29", "יום ירושלים"),
-            ("2022-08-07", "(נצפה) תשעה באב"),
+            ("2022-08-07", "תשעה באב (נצפה)"),
             ("2022-10-11", "חול המועד סוכות"),
             ("2022-10-12", "חול המועד סוכות"),
             ("2022-10-13", "חול המועד סוכות"),
@@ -449,6 +449,44 @@ class TestIsrael(CommonCountryTests, TestCase):
             ("2023-12-15", "חנוכה"),
         )
 
+    def test_l10n_default(self):
+        self.assertLocalizedHolidays(
+            ("2021-02-25", "תענית אסתר"),
+            ("2021-02-26", "פורים"),
+            ("2021-03-28", "פסח"),
+            ("2021-03-29", "חול המועד פסח"),
+            ("2021-03-30", "חול המועד פסח"),
+            ("2021-03-31", "חול המועד פסח"),
+            ("2021-04-01", "חול המועד פסח"),
+            ("2021-04-02", "חול המועד פסח"),
+            ("2021-04-03", "שביעי של פסח"),
+            ("2021-04-14", "יום הזיכרון לחללי מערכות ישראל ונפגעי פעולות האיבה (נצפה)"),
+            ("2021-04-15", "יום העצמאות (נצפה)"),
+            ("2021-04-30", 'ל"ג בעומר'),
+            ("2021-05-10", "יום ירושלים"),
+            ("2021-05-17", "שבועות"),
+            ("2021-07-18", "תשעה באב"),
+            ("2021-09-07", "ראש השנה"),
+            ("2021-09-08", "ראש השנה"),
+            ("2021-09-16", "יום כיפור"),
+            ("2021-09-21", "סוכות"),
+            ("2021-09-22", "חול המועד סוכות"),
+            ("2021-09-23", "חול המועד סוכות"),
+            ("2021-09-24", "חול המועד סוכות"),
+            ("2021-09-25", "חול המועד סוכות"),
+            ("2021-09-26", "חול המועד סוכות"),
+            ("2021-09-28", "שמחת תורה/שמיני עצרת"),
+            ("2021-11-04", "סיגד"),
+            ("2021-11-29", "חנוכה"),
+            ("2021-11-30", "חנוכה"),
+            ("2021-12-01", "חנוכה"),
+            ("2021-12-02", "חנוכה"),
+            ("2021-12-03", "חנוכה"),
+            ("2021-12-04", "חנוכה"),
+            ("2021-12-05", "חנוכה"),
+            ("2021-12-06", "חנוכה"),
+        )
+
     def test_l10n_en_us(self):
         self.assertLocalizedHolidays(
             "en_US",
