@@ -20,159 +20,170 @@ from tests.common import CommonCountryTests
 class TestNetherlands(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        super().setUpClass(Netherlands)
+        cls.full_range = range(1966, 2050)
+        super().setUpClass(Netherlands, years=cls.full_range)
+        cls.optional_holidays = Netherlands(categories=OPTIONAL, years=cls.full_range)
 
     def test_country_aliases(self):
         self.assertAliases(Netherlands, NL, NLD)
 
-    def test_queens_day_between_1891_and_1948(self):
-        name = "Koninginnedag"
-        self.assertHolidayName(name, "1891-08-31", "1901-08-31", "1948-08-31")
-        self.assertNoHolidayName(name, Netherlands(years=1890))
+    def test_no_holidays(self):
+        self.assertNoHolidays(Netherlands(categories=Netherlands.supported_categories, years=1964))
 
-    def test_queens_day_between_1891_and_1948_substituted_later(self):
+    def test_new_years_day(self):
+        self.assertHolidayName("Nieuwjaarsdag", (f"{year}-01-01" for year in self.full_range))
+
+    def test_good_friday(self):
+        name = "Goede Vrijdag"
         self.assertHolidayName(
-            "Koninginnedag",
-            "1902-09-01",
-            "1913-09-01",
-            "1919-09-01",
-            "1924-09-01",
-            "1930-09-01",
-            "1941-09-01",
-            "1947-09-01",
-        )
-        self.assertNoHoliday(
-            "1902-08-31",
-            "1913-08-31",
-            "1919-08-31",
-            "1924-08-31",
-            "1930-08-31",
-            "1941-08-31",
-            "1947-08-31",
+            name,
+            "2020-04-10",
+            "2021-04-02",
+            "2022-04-15",
+            "2023-04-07",
+            "2024-03-29",
+            "2025-04-18",
         )
+        self.assertHolidayName(name, self.full_range)
 
-    def test_queens_day_between_1949_and_2013(self):
-        name = "Koninginnedag"
-        self.assertHolidayName(name, "1949-04-30", "1970-04-30", "2013-04-30")
-        self.assertNoHoliday("2014-04-30")
-        self.assertNoHolidayName(name, Netherlands(years=2014))
-
-    def test_queens_day_between_1949_and_1980_substituted_later(self):
+    def test_easter_sunday(self):
+        name = "Eerste paasdag"
         self.assertHolidayName(
-            "Koninginnedag",
-            "1950-05-01",
-            "1961-05-01",
+            name,
+            "2020-04-12",
+            "2021-04-04",
+            "2022-04-17",
+            "2023-04-09",
+            "2024-03-31",
+            "2025-04-20",
+        )
+        self.assertHolidayName(name, self.full_range)
+
+    def test_easter_monday(self):
+        name = "Tweede paasdag"
+        self.assertHolidayName(
+            name,
+            "2020-04-13",
+            "2021-04-05",
+            "2022-04-18",
+            "2023-04-10",
+            "2024-04-01",
+            "2025-04-21",
+        )
+        self.assertHolidayName(name, self.full_range)
+
+    def test_queens_day(self):
+        name = "Koninginnedag"
+        self.assertHolidayName(
+            name,
             "1967-05-01",
             "1972-05-01",
             "1978-05-01",
-        )
-        self.assertNoHoliday(
-            "1950-04-30",
-            "1961-04-30",
-            "1967-04-30",
-            "1972-04-30",
-            "1978-04-30",
-        )
-
-    def test_queens_day_between_1980_and_2013_substituted_earlier(self):
-        self.assertHolidayName(
-            "Koninginnedag",
             "1989-04-29",
             "1995-04-29",
             "2000-04-29",
             "2006-04-29",
+            "2013-04-30",
         )
-        self.assertNoHoliday(
+        self.assertHolidayName(name, range(1966, 2014))
+        self.assertNoHolidayName(
+            name,
+            "1967-04-30",
+            "1972-04-30",
+            "1978-04-30",
             "1995-04-30",
             "1989-04-30",
             "2000-04-30",
             "2006-04-30",
         )
+        self.assertNoHolidayName(name, range(2014, 2050))
 
-    def test_kings_day_after_2014(self):
+    def test_king_day(self):
         name = "Koningsdag"
-        self.assertHolidayName(name, "2015-04-27", "2020-04-27", "2023-04-27")
-        self.assertNoHoliday("2013-04-27")
-        self.assertNoHolidayName(name, Netherlands(years=2013))
-
-    def test_kings_day_after_2014_substituted_earlier(self):
         self.assertHolidayName(
-            "Koningsdag",
-            "2014-04-26",
+            name,
+            "2016-04-27",
+            "2017-04-27",
+            "2018-04-27",
+            "2019-04-27",
+            "2020-04-27",
+            "2021-04-27",
+            "2022-04-27",
+            "2023-04-27",
+            "2024-04-27",
             "2025-04-26",
             "2031-04-26",
             "2036-04-26",
         )
-        self.assertNoHoliday(
+        self.assertHolidayName(name, range(2014, 2050))
+        self.assertNoHolidayName(
+            name,
             "2014-04-27",
             "2025-04-27",
             "2031-04-27",
             "2036-04-27",
         )
+        self.assertNoHolidayName(name, range(1966, 2014))
 
     def test_liberation_day(self):
         name = "Bevrijdingsdag"
+        # PUBLIC.
+        self.assertHolidayName(
+            name, (f"{year}-05-05" for year in self.full_range if year % 5 == 0)
+        )
+        self.assertNoHolidayName(
+            name, (f"{year}-05-05" for year in self.full_range if year % 5 != 0)
+        )
+        # OPTIONAL.
+        self.assertHolidayName(
+            name, self.optional_holidays, (f"{year}-05-05" for year in range(1982, 2050))
+        )
+        self.assertNoHolidayName(name, self.optional_holidays, range(1966, 1982))
+
+    def test_ascension_day(self):
+        name = "Hemelvaartsdag"
         self.assertHolidayName(
             name,
-            "1950-05-05",
-            "1955-05-05",
-            "1960-05-05",
-            "1965-05-05",
-            "1970-05-05",
-            "1975-05-05",
-            "1980-05-05",
-            "1985-05-05",
-            "1990-05-05",
-            "1995-05-05",
-            "2000-05-05",
-            "2005-05-05",
-            "2010-05-05",
-            "2015-05-05",
-            "2020-05-05",
-        )
-        self.assertNoHoliday(
-            "1949-05-05",
-            "1971-05-05",
-            "1991-05-05",
+            "2020-05-21",
+            "2021-05-13",
+            "2022-05-26",
+            "2023-05-18",
+            "2024-05-09",
+            "2025-05-29",
         )
+        self.assertHolidayName(name, self.full_range)
 
-        opt_holidays = Netherlands(categories=OPTIONAL, years=range(1980, 2050))
-        self.assertHolidayName(name, opt_holidays, (f"{year}-05-05" for year in range(1990, 2050)))
-        self.assertNoHolidayName(name, Netherlands(categories=OPTIONAL, years=(1949, 1971, 1989)))
-
-    def test_2017(self):
-        self.assertHolidays(
-            ("2017-01-01", "Nieuwjaarsdag"),
-            ("2017-04-16", "Eerste paasdag"),
-            ("2017-04-17", "Tweede paasdag"),
-            ("2017-04-27", "Koningsdag"),
-            ("2017-05-25", "Hemelvaartsdag"),
-            ("2017-06-04", "Eerste Pinksterdag"),
-            ("2017-06-05", "Tweede Pinksterdag"),
-            ("2017-12-25", "Eerste Kerstdag"),
-            ("2017-12-26", "Tweede Kerstdag"),
+    def test_whit_sunday(self):
+        name = "Eerste Pinksterdag"
+        self.assertHolidayName(
+            name,
+            "2020-05-31",
+            "2021-05-23",
+            "2022-06-05",
+            "2023-05-28",
+            "2024-05-19",
+            "2025-06-08",
         )
+        self.assertHolidayName(name, self.full_range)
 
-    def test_2020(self):
-        self.assertHolidays(
-            ("2020-01-01", "Nieuwjaarsdag"),
-            ("2020-04-12", "Eerste paasdag"),
-            ("2020-04-13", "Tweede paasdag"),
-            ("2020-04-27", "Koningsdag"),
-            ("2020-05-05", "Bevrijdingsdag"),
-            ("2020-05-21", "Hemelvaartsdag"),
-            ("2020-05-31", "Eerste Pinksterdag"),
-            ("2020-06-01", "Tweede Pinksterdag"),
-            ("2020-12-25", "Eerste Kerstdag"),
-            ("2020-12-26", "Tweede Kerstdag"),
+    def test_whit_monday(self):
+        name = "Tweede Pinksterdag"
+        self.assertHolidayName(
+            name,
+            "2020-06-01",
+            "2021-05-24",
+            "2022-06-06",
+            "2023-05-29",
+            "2024-05-20",
+            "2025-06-09",
         )
+        self.assertHolidayName(name, self.full_range)
 
-    def test_2023_optional(self):
-        self.assertHolidays(
-            Netherlands(categories=OPTIONAL, years=2023),
-            ("2023-04-07", "Goede Vrijdag"),
-            ("2023-05-05", "Bevrijdingsdag"),
-        )
+    def test_christmas_day(self):
+        self.assertHolidayName("Eerste Kerstdag", (f"{year}-12-25" for year in self.full_range))
+
+    def test_second_day_of_christmas(self):
+        self.assertHolidayName("Tweede Kerstdag", (f"{year}-12-26" for year in self.full_range))
 
     def test_l10n_default(self):
         self.assertLocalizedHolidays(
@@ -221,6 +232,22 @@ class TestNetherlands(CommonCountryTests, TestCase):
             ("2022-12-26", "Twadde Krystdei"),
         )
 
+    def test_l10n_th(self):
+        self.assertLocalizedHolidays(
+            "th",
+            ("2022-01-01", "วันขึ้นปีใหม่"),
+            ("2022-04-15", "วันศุกร์ประเสริฐ"),
+            ("2022-04-17", "วันอาทิตย์อีสเตอร์"),
+            ("2022-04-18", "วันจันทร์อีสเตอร์"),
+            ("2022-04-27", "วันเฉลิมพระชนมพรรษาสมเด็จพระราชาธิบดี"),
+            ("2022-05-05", "วันประกาศอิสรภาพ"),
+            ("2022-05-26", "วันสมโภชพระเยซูเจ้าเสด็จขึ้นสวรรค์"),
+            ("2022-06-05", "วันสมโภชพระจิตเจ้า"),
+            ("2022-06-06", "วันจันทร์หลังวันสมโภชพระจิตเจ้า"),
+            ("2022-12-25", "วันคริสต์มาสวันแรก"),
+            ("2022-12-26", "วันคริสต์มาสวันที่สอง"),
+        )
+
     def test_l10n_uk(self):
         self.assertLocalizedHolidays(
             "uk",
