@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -19,13 +19,14 @@ from tests.common import CommonCountryTests
 class TestPeru(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        super().setUpClass(Peru)
+        super().setUpClass(Peru, years=range(1950, 2050))
 
     def test_country_aliases(self):
         self.assertAliases(Peru, PE, PER)
 
     def test_2019(self):
         self.assertHolidayDates(
+            Peru(years=2019),
             "2019-01-01",
             "2019-04-18",
             "2019-04-19",
@@ -43,6 +44,7 @@ class TestPeru(CommonCountryTests, TestCase):
 
     def test_2022(self):
         self.assertHolidayDates(
+            Peru(years=2022),
             "2022-01-01",
             "2022-04-14",
             "2022-04-15",
@@ -60,6 +62,16 @@ class TestPeru(CommonCountryTests, TestCase):
             "2022-12-25",
         )
 
+    def test_battle_of_arica_and_flag_day(self):
+        name = "Batalla de Arica y Día de la Bandera"
+        self.assertHolidayName(name, (f"{year}-06-07" for year in range(2024, 2050)))
+        self.assertNoHolidayName(name, range(1950, 2024))
+
+    def test_peruvian_air_force_day(self):
+        name = "Día de la Fuerza Aérea del Perú"
+        self.assertHolidayName(name, (f"{year}-07-23" for year in range(2023, 2050)))
+        self.assertNoHolidayName(name, range(1950, 2023))
+
     def test_l10n_default(self):
         self.assertLocalizedHolidays(
             ("2022-01-01", "Año Nuevo"),
