@@ -47,8 +47,9 @@ class TestPR(CommonCountryTests, TestCase):
             ("2022-03-17", "Saint Patrick's Day"),
             ("2022-03-22", "Emancipation Day"),
             ("2022-04-15", "Good Friday"),
+            ("2022-05-08", "Mother's Day"),
             ("2022-05-30", "Memorial Day"),
-            ("2022-06-19", "Juneteenth National Independence Day"),
+            ("2022-06-19", "Father's Day; Juneteenth National Independence Day"),
             ("2022-06-20", "Juneteenth National Independence Day (observed)"),
             ("2022-07-04", "Independence Day"),
             ("2022-07-25", "Constitution Day"),
@@ -73,8 +74,9 @@ class TestPR(CommonCountryTests, TestCase):
             ("2022-03-17", "วันนักบุญแพทริก"),
             ("2022-03-22", "วันเลิกทาส"),
             ("2022-04-15", "วันศุกร์ประเสริฐ"),
+            ("2022-05-08", "วันแม่"),
             ("2022-05-30", "วันรำลึก"),
-            ("2022-06-19", "วันประกาศอิสรภาพแห่งชาติจูนทีนท์"),
+            ("2022-06-19", "วันประกาศอิสรภาพแห่งชาติจูนทีนท์; วันพ่อ"),
             ("2022-06-20", "ชดเชยวันประกาศอิสรภาพแห่งชาติจูนทีนท์"),
             ("2022-07-04", "วันประกาศอิสรภาพ"),
             ("2022-07-25", "วันรัฐธรรมนูญ"),
