@@ -160,6 +160,24 @@ class TestQatar(CommonCountryTests, TestCase):
         self.assertNoHolidayName(name, self.bank_holidays, range(1971, 2010))
         self.assertNoHolidayName(name)
 
+    def test_weekend(self):
+        for dt in (
+            "2003-07-24",  # THU.
+            "2003-07-25",  # FRI.
+            "2003-07-31",  # THU.
+            "2003-08-01",  # FRI.
+            "2003-08-02",  # SAT.
+        ):
+            self.assertTrue(self.holidays.is_weekend(dt))
+
+        for dt in (
+            "2003-07-26",  # SAT.
+            "2003-07-27",  # SUN.
+            "2003-08-03",  # SUN.
+            "2003-08-07",  # THU.
+        ):
+            self.assertFalse(self.holidays.is_weekend(dt))
+
     def test_2011(self):
         self.assertHolidays(
             Qatar(years=2011),
