@@ -288,6 +288,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (SEP, 15): {"CB"},
             (OCT, 9): {"VC"},
             (NOV, 17): {"CE", "ML"},
+            (DEC, 3): {"NC"},
         }
         self._assertVariableDays(2010, province_days)
 
@@ -332,6 +333,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (SEP, 15): {"CB"},
             (OCT, 25): {"PV"},
             (NOV, 7): {"CE", "ML"},
+            (DEC, 3): {"NC"},
             (DEC, 26): {"AN", "AR", "AS", "CE", "CL", "CN", "CT", "EX", "IB", "ML", "NC"},
         }
         self._assertVariableDays(2011, province_days)
@@ -377,6 +379,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (OCT, 25): {"PV"},
             (OCT, 26): {"ML"},
             (OCT, 27): {"CE"},
+            (DEC, 3): {"NC"},
             (DEC, 26): {"CT"},
         }
         self._assertVariableDays(2012, province_days)
@@ -435,6 +438,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (OCT, 9): {"VC"},
             (OCT, 15): {"CE", "ML"},
             (OCT, 25): {"PV"},
+            (DEC, 3): {"NC"},
             (DEC, 9): {"AN", "AR", "AS", "CE", "CL", "EX", "MC", "RI"},
             (DEC, 26): {"CT", "IB"},
         }
@@ -481,6 +485,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (OCT, 9): {"VC"},
             (OCT, 13): {"AN", "AR", "AS", "CE", "CL", "EX"},
             (OCT, 25): {"PV"},
+            (DEC, 3): {"NC"},
             (DEC, 26): {"CT", "IB"},
         }
         self._assertVariableDays(2014, province_days)
@@ -523,6 +528,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (SEP, 25): {"CE", "ML"},
             (OCT, 9): {"VC"},
             (NOV, 2): {"AN", "AR", "AS", "CB", "CE", "CL", "CN", "EX", "GA", "IB"},
+            (DEC, 3): {"NC"},
             (DEC, 7): {"AN", "AR", "AS", "CE", "CL", "CM", "EX", "IB", "MC", "ML", "RI", "VC"},
             (DEC, 26): {"CT"},
         }
@@ -570,6 +576,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (SEP, 12): {"CE", "ML"},
             (SEP, 15): {"CB"},
             (OCT, 7): {"PV"},
+            (DEC, 3): {"NC"},
             (DEC, 26): {
                 "AN",
                 "AR",
@@ -633,6 +640,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (SEP, 11): {"CT"},
             (SEP, 15): {"CB"},
             (OCT, 9): {"VC"},
+            (DEC, 4): {"NC"},
             (DEC, 26): {"CT"},
         }
         self._assertVariableDays(2017, province_days)
@@ -674,6 +682,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (SEP, 11): {"CT"},
             (SEP, 15): {"CB"},
             (OCT, 9): {"VC"},
+            (DEC, 3): {"NC"},
             (DEC, 26): {"CT"},
         }
         self._assertVariableDays(2018, province_days)
@@ -718,6 +727,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (SEP, 9): {"AS", "EX"},
             (SEP, 11): {"CT"},
             (OCT, 9): {"VC"},
+            (DEC, 3): {"NC"},
             (DEC, 9): {"AN", "AR", "AS", "CB", "CL", "EX", "MD", "ML", "RI"},
             (DEC, 26): {"CT", "IB"},
         }
@@ -763,6 +773,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (SEP, 15): {"CB"},
             (OCT, 9): {"VC"},
             (NOV, 2): {"AN", "AR", "AS", "CL", "EX", "MD"},
+            (DEC, 3): {"NC"},
             (DEC, 7): {
                 "AN",
                 "AR",
@@ -823,6 +834,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (SEP, 11): {"CT"},
             (SEP, 15): {"CB"},
             (OCT, 9): {"VC"},
+            (DEC, 3): {"NC"},
         }
         self._assertVariableDays(2021, province_days)
 
@@ -871,6 +883,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (SEP, 6): {"PV"},
             (SEP, 8): {"AS", "EX"},
             (SEP, 15): {"CB"},
+            (DEC, 3): {"NC"},
             (DEC, 26): {
                 "AN",
                 "AR",
@@ -935,6 +948,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (SEP, 11): {"CT"},
             (SEP, 15): {"CB"},
             (OCT, 9): {"VC"},
+            (DEC, 4): {"NC"},
             (DEC, 26): {"CT"},
         }
         self._assertVariableDays(2023, province_days)
@@ -978,6 +992,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (SEP, 9): {"AS"},
             (SEP, 11): {"CT"},
             (OCT, 9): {"VC"},
+            (DEC, 3): {"NC"},
             (DEC, 9): {"AN", "AR", "AS", "CL", "EX", "MC", "ML"},
             (DEC, 26): {"CT"},
         }
@@ -1026,6 +1041,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (SEP, 15): {"CB"},
             (OCT, 9): {"VC"},
             (OCT, 13): {"AN", "AR", "AS", "CL", "EX"},
+            (DEC, 3): {"NC"},
             (DEC, 26): {"CT", "IB"},
         }
         self._assertVariableDays(2025, province_days)
@@ -1035,7 +1051,7 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-01-02", "Lunes siguiente a Año Nuevo"),
             ("2023-01-06", "Epifanía del Señor"),
             ("2023-02-21", "Martes de Carnaval"),
-            ("2023-02-28", "Día de Andalucia"),
+            ("2023-02-28", "Día de Andalucía"),
             ("2023-03-01", "Día de las Islas Baleares"),
             ("2023-03-20", "Lunes siguiente a San José"),
             ("2023-04-06", "Jueves Santo"),
@@ -1063,12 +1079,54 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-10-09", "Día de la Comunidad Valenciana"),
             ("2023-10-12", "Fiesta Nacional de España"),
             ("2023-11-01", "Todos los Santos"),
+            ("2023-12-04", "Lunes siguiente a San Francisco Javier"),
             ("2023-12-06", "Día de la Constitución Española"),
             ("2023-12-08", "Inmaculada Concepción"),
             ("2023-12-25", "Natividad del Señor"),
             ("2023-12-26", "San Esteban"),
         )
 
+    def test_l10n_ca(self):
+        self.assertLocalizedHolidays(
+            "ca",
+            ("2023-01-02", "Dilluns següent a Cap d'Any"),
+            ("2023-01-06", "Reis"),
+            ("2023-02-21", "Dimarts de Carnaval"),
+            ("2023-02-28", "Dia d'Andalusia"),
+            ("2023-03-01", "Dia de les Illes Balears"),
+            ("2023-03-20", "Dilluns següent a Sant Josep"),
+            ("2023-04-06", "Dijous Sant"),
+            ("2023-04-07", "Divendres Sant"),
+            ("2023-04-10", "Dilluns de Pasqua"),
+            ("2023-04-21", "Festa de l'Eid Fitr"),
+            ("2023-04-24", "Dilluns següent a Dia de Sant Jordi"),
+            ("2023-05-01", "Festa del Treball"),
+            ("2023-05-02", "Festa de la Comunitat de Madrid"),
+            ("2023-05-17", "Dia de les Lletres Gallegues"),
+            ("2023-05-30", "Dia de les Canàries"),
+            ("2023-05-31", "Dia de Castella-la Manxa"),
+            ("2023-06-08", "Corpus Christi"),
+            ("2023-06-09", "Dia de La Rioja; Dia de la Regió de Múrcia"),
+            ("2023-06-24", "Sant Joan"),
+            ("2023-06-29", "Festa del Sacrifici-Aid Al Adha; Festa del Sacrifici-Eidul Adha"),
+            ("2023-07-25", "Dia Nacional de Galícia; Sant Jaume Apòstol"),
+            ("2023-07-28", "Dia de les Institucions de Cantàbria"),
+            ("2023-08-05", "Nostra Senyora d'Àfrica"),
+            ("2023-08-15", "Assumpció de la Verge"),
+            ("2023-09-02", "Dia de Ceuta"),
+            ("2023-09-08", "Dia d'Astúries; Dia d'Extremadura"),
+            ("2023-09-11", "Diada Nacional de Catalunya"),
+            ("2023-09-15", "La Bien Aparecida"),
+            ("2023-10-09", "Dia de la Comunitat Valenciana"),
+            ("2023-10-12", "Festa Nacional d'Espanya"),
+            ("2023-11-01", "Tots Sants"),
+            ("2023-12-04", "Dilluns següent a Sant Francesc Xavier"),
+            ("2023-12-06", "Dia de la Constitució Espanyola"),
+            ("2023-12-08", "Immaculada Concepció"),
+            ("2023-12-25", "Nativitat del Senyor"),
+            ("2023-12-26", "Sant Esteve"),
+        )
+
     def test_l10n_en_us(self):
         self.assertLocalizedHolidays(
             "en_US",
@@ -1097,12 +1155,13 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-08-05", "Santa Maria of Africa"),
             ("2023-08-15", "Assumption Day"),
             ("2023-09-02", "Ceuta Day"),
-            ("2023-09-08", "Asturia Day; Extremadura Day"),
+            ("2023-09-08", "Asturias Day; Extremadura Day"),
             ("2023-09-11", "National Day of Catalonia"),
-            ("2023-09-15", "Our Lady of the Bien Aparecida"),
+            ("2023-09-15", "Our Lady of Bien Aparecida"),
             ("2023-10-09", "Valencian Community Day"),
             ("2023-10-12", "National Day"),
             ("2023-11-01", "All Saints' Day"),
+            ("2023-12-04", "Monday following Saint Francis Xavier's Day"),
             ("2023-12-06", "Constitution Day"),
             ("2023-12-08", "Immaculate Conception"),
             ("2023-12-25", "Christmas Day"),
@@ -1143,6 +1202,7 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-10-09", "День Валенсії"),
             ("2023-10-12", "Національний день Іспанії"),
             ("2023-11-01", "День усіх святих"),
+            ("2023-12-04", "Понеділок після День Святого Франциска Ксаверія"),
             ("2023-12-06", "День Конституції Іспанії"),
             ("2023-12-08", "Непорочне зачаття Діви Марії"),
             ("2023-12-25", "Різдво Христове"),
