@@ -20,14 +20,25 @@ from tests.common import CommonCountryTests
 class TestSwitzerland(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        years = range(1970, 2050)
-        super().setUpClass(Switzerland, years=years)
+        cls.full_range = range(1970, 2050)
+        super().setUpClass(Switzerland, years=cls.full_range)
         cls.subdiv_holidays = {
-            subdiv: CH(subdiv=subdiv, years=years) for subdiv in CH.subdivisions
+            subdiv: Switzerland(subdiv=subdiv, years=cls.full_range)
+            for subdiv in Switzerland.subdivisions
         }
-        cls.subdiv_holidays_optional = {
-            subdiv: CH(categories=OPTIONAL, subdiv=subdiv, years=years)
-            for subdiv in CH.subdivisions
+        cls.subdiv_half_day_holidays = {
+            subdiv: Switzerland(categories=HALF_DAY, subdiv=subdiv, years=cls.full_range)
+            for subdiv in Switzerland.subdivisions
+        }
+        cls.subdiv_optional_holidays = {
+            subdiv: Switzerland(categories=OPTIONAL, subdiv=subdiv, years=cls.full_range)
+            for subdiv in Switzerland.subdivisions
+        }
+        cls.subdiv_optional_holidays_non_observed = {
+            subdiv: Switzerland(
+                categories=OPTIONAL, observed=False, subdiv=subdiv, years=cls.full_range
+            )
+            for subdiv in Switzerland.subdivisions
         }
 
     def test_country_aliases(self):
@@ -35,9 +46,9 @@ class TestSwitzerland(CommonCountryTests, TestCase):
 
     def test_all_holidays_present(self):
         y_2018 = set()
-        for p in CH.subdivisions:
+        for p in Switzerland.subdivisions:
             y_2018.update(
-                CH(categories=(HALF_DAY, OPTIONAL, PUBLIC), years=2018, subdiv=p).values()
+                Switzerland(categories=(HALF_DAY, OPTIONAL, PUBLIC), years=2018, subdiv=p).values()
             )
         all_h = {  # Holidays names in their chronological order.
             "Neujahrstag",
@@ -46,23 +57,31 @@ class TestSwitzerland(CommonCountryTests, TestCase):
             "Jahrestag der Ausrufung der Republik",
             "Josefstag",
             "Näfelser Fahrt",
+            "Vortag vor Karfreitag",
             "Karfreitag",
             "Ostermontag",
+            "Sechseläuten",
             "Tag der Arbeit",
+            "Vortag vor Auffahrt",
             "Auffahrt",
+            "Brückentag nach Auffahrt",
             "Pfingstmontag",
             "Fronleichnam",
             "Fest der Unabhängigkeit",
             "Peter und Paul",
             "Nationalfeiertag",
             "Mariä Himmelfahrt",
+            "Knabenschiessen",
             "Bettagsmontag",
             "Bruder Klaus",
             "Allerheiligen",
             "Mariä Empfängnis",
             "Genfer Bettag",
+            "Heiligabend",
             "Weihnachten",
             "Stephanstag",
+            "Brückentag",
+            "Vortag vor Neujahr",
             "Wiederherstellung der Republik",
         }
 
@@ -74,11 +93,11 @@ class TestSwitzerland(CommonCountryTests, TestCase):
 
     def test_fixed_holidays(self):
         # New Year's Day.
-        self.assertHolidayName("Neujahrstag", (f"{year}-01-01" for year in range(1970, 2050)))
+        self.assertHolidayName("Neujahrstag", (f"{year}-01-01" for year in self.full_range))
         # National Day.
-        self.assertHolidayName("Nationalfeiertag", (f"{year}-08-01" for year in range(1970, 2050)))
+        self.assertHolidayName("Nationalfeiertag", (f"{year}-08-01" for year in self.full_range))
         # Christmas Day.
-        self.assertHolidayName("Weihnachten", (f"{year}-12-25" for year in range(1970, 2050)))
+        self.assertHolidayName("Weihnachten", (f"{year}-12-25" for year in self.full_range))
 
     def test_berchtolds_day(self):
         name = "Berchtoldstag"
@@ -90,19 +109,19 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv in subdivs_that_have:
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-01-02" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-01-02" for year in self.full_range)
                 )
             elif subdiv != "NE":
-                self.assertNoHoliday(holidays, (f"{year}-01-02" for year in range(1970, 2050)))
+                self.assertNoHoliday(holidays, (f"{year}-01-02" for year in self.full_range))
                 self.assertNoHolidayName(name, holidays)
 
-        for subdiv, holidays in self.subdiv_holidays_optional.items():
+        for subdiv, holidays in self.subdiv_optional_holidays.items():
             if subdiv in subdivs_optional:
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-01-02" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-01-02" for year in self.full_range)
                 )
             else:
-                self.assertNoHoliday(holidays, (f"{year}-01-02" for year in range(1970, 2050)))
+                self.assertNoHoliday(holidays, (f"{year}-01-02" for year in self.full_range))
                 self.assertNoHolidayName(name, holidays)
 
         # When holiday present in NE.
@@ -112,7 +131,7 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         )
         self.assertNoHoliday(
             self.subdiv_holidays["NE"],
-            (f"{year}-01-02" for year in set(range(1970, 2050)).difference(ne_years)),
+            (f"{year}-01-02" for year in set(self.full_range).difference(ne_years)),
         )
 
     def test_epiphany(self):
@@ -124,10 +143,10 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv in subdivs_that_have:
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-01-06" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-01-06" for year in self.full_range)
                 )
             else:
-                self.assertNoHoliday(holidays, (f"{year}-01-06" for year in range(1970, 2050)))
+                self.assertNoHoliday(holidays, (f"{year}-01-06" for year in self.full_range))
                 self.assertNoHolidayName(name, holidays)
 
     def test_republic_day(self):
@@ -138,10 +157,10 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "NE":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-03-01" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-03-01" for year in self.full_range)
                 )
             else:
-                self.assertNoHoliday(holidays, (f"{year}-03-01" for year in range(1970, 2050)))
+                self.assertNoHoliday(holidays, (f"{year}-03-01" for year in self.full_range))
                 self.assertNoHolidayName(name, holidays)
 
     def test_st_josephs_day(self):
@@ -153,10 +172,10 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv in subdivs_that_have:
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-03-19" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-03-19" for year in self.full_range)
                 )
             else:
-                self.assertNoHoliday(holidays, (f"{year}-03-19" for year in range(1970, 2050)))
+                self.assertNoHoliday(holidays, (f"{year}-03-19" for year in self.full_range))
                 self.assertNoHolidayName(name, holidays)
 
     def test_nafels_ride(self):
@@ -191,7 +210,7 @@ class TestSwitzerland(CommonCountryTests, TestCase):
                 self.assertNoHoliday(holidays, known_good)
                 self.assertNoHolidayName(name, holidays)
 
-        self.assertNoHolidayName(name, CH(subdiv="GL", years=1834))
+        self.assertNoHolidayName(name, Switzerland(subdiv="GL", years=1834))
 
     def test_good_friday(self):
         name = "Karfreitag"
@@ -217,7 +236,7 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         )
         subdivs_that_dont = {"TI", "VS"}
         subdivs_optional = {"GR"}
-        subdivs_that_have = set(CH.subdivisions) - subdivs_that_dont - subdivs_optional
+        subdivs_that_have = set(Switzerland.subdivisions) - subdivs_that_dont - subdivs_optional
 
         self.assertNoHolidayName(name)
 
@@ -228,7 +247,7 @@ class TestSwitzerland(CommonCountryTests, TestCase):
                 self.assertNoHoliday(holidays, known_good)
                 self.assertNoHolidayName(name, holidays)
 
-        for subdiv, holidays in self.subdiv_holidays_optional.items():
+        for subdiv, holidays in self.subdiv_optional_holidays.items():
             if subdiv in subdivs_optional:
                 self.assertHolidayName(name, holidays, known_good)
             else:
@@ -259,7 +278,7 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         )
         subdivs_that_dont = {"NE", "SO"}
         subdivs_optional = {"FR", "NW", "OW", "VS", "ZG"}
-        subdivs_that_have = set(CH.subdivisions) - subdivs_that_dont - subdivs_optional
+        subdivs_that_have = set(Switzerland.subdivisions) - subdivs_that_dont - subdivs_optional
 
         self.assertNoHolidayName(name)
 
@@ -270,7 +289,7 @@ class TestSwitzerland(CommonCountryTests, TestCase):
                 self.assertNoHoliday(holidays, known_good)
                 self.assertNoHolidayName(name, holidays)
 
-        for subdiv, holidays in self.subdiv_holidays_optional.items():
+        for subdiv, holidays in self.subdiv_optional_holidays.items():
             if subdiv in subdivs_optional:
                 self.assertHolidayName(name, holidays, known_good)
             else:
@@ -286,19 +305,24 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv in subdivs_that_have:
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-05-01" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-05-01" for year in self.full_range)
                 )
             else:
                 self.assertNoHolidayName(
-                    name, holidays, (f"{year}-05-01" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-05-01" for year in self.full_range)
                 )
                 self.assertNoHolidayName(name, holidays)
 
-        self.assertHolidayName(
-            name,
-            CH(categories=HALF_DAY, subdiv="SO", years=range(1970, 2050)),
-            (f"{year}-05-01" for year in range(1970, 2050)),
-        )
+        for subdiv, holidays in self.subdiv_half_day_holidays.items():
+            if subdiv == "SO":
+                self.assertHolidayName(
+                    name, holidays, (f"{year}-05-01" for year in self.full_range)
+                )
+            else:
+                self.assertNoHolidayName(
+                    name, holidays, (f"{year}-05-01" for year in self.full_range)
+                )
+                self.assertNoHolidayName(name, holidays)
 
     def test_ascension_day(self):
         name = "Auffahrt"
@@ -324,7 +348,7 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         )
 
         self.assertHolidayName(name, known_good)
-        self.assertHolidayName(name, range(1970, 2050))
+        self.assertHolidayName(name, self.full_range)
         for holidays in self.subdiv_holidays.values():
             self.assertHolidayName(name, holidays, known_good)
 
@@ -353,7 +377,7 @@ class TestSwitzerland(CommonCountryTests, TestCase):
 
         subdivs_that_dont = {"NE", "SO"}
         subdivs_optional = {"FR", "NW", "OW", "VS", "ZG"}
-        subdivs_that_have = set(CH.subdivisions) - subdivs_that_dont - subdivs_optional
+        subdivs_that_have = set(Switzerland.subdivisions) - subdivs_that_dont - subdivs_optional
 
         self.assertNoHolidayName(name)
 
@@ -364,7 +388,7 @@ class TestSwitzerland(CommonCountryTests, TestCase):
                 self.assertNoHoliday(holidays, known_good)
                 self.assertNoHolidayName(name, holidays)
 
-        for subdiv, holidays in self.subdiv_holidays_optional.items():
+        for subdiv, holidays in self.subdiv_optional_holidays.items():
             if subdiv in subdivs_optional:
                 self.assertHolidayName(name, holidays, known_good)
             else:
@@ -418,11 +442,11 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "JU":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-06-23" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-06-23" for year in self.full_range)
                 )
             else:
                 self.assertNoHolidayName(
-                    name, holidays, (f"{year}-06-23" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-06-23" for year in self.full_range)
                 )
                 self.assertNoHolidayName(name, holidays)
 
@@ -434,10 +458,10 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "TI":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-06-29" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-06-29" for year in self.full_range)
                 )
             else:
-                self.assertNoHoliday(holidays, (f"{year}-06-29" for year in range(1970, 2050)))
+                self.assertNoHoliday(holidays, (f"{year}-06-29" for year in self.full_range))
                 self.assertNoHolidayName(name, holidays)
 
     def test_assumption_day(self):
@@ -449,10 +473,10 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv in subdivs_that_have:
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-08-15" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-08-15" for year in self.full_range)
                 )
             else:
-                self.assertNoHoliday(holidays, (f"{year}-08-15" for year in range(1970, 2050)))
+                self.assertNoHoliday(holidays, (f"{year}-08-15" for year in self.full_range))
                 self.assertNoHolidayName(name, holidays)
 
     def test_prayer_monday(self):
@@ -488,10 +512,10 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "OW":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-09-25" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-09-25" for year in self.full_range)
                 )
             else:
-                self.assertNoHoliday(holidays, (f"{year}-09-25" for year in range(1970, 2050)))
+                self.assertNoHoliday(holidays, (f"{year}-09-25" for year in self.full_range))
                 self.assertNoHolidayName(name, holidays)
 
     def test_all_saints_day(self):
@@ -517,10 +541,10 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv in subdivs_that_have:
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-11-01" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-11-01" for year in self.full_range)
                 )
             else:
-                self.assertNoHoliday(holidays, (f"{year}-11-01" for year in range(1970, 2050)))
+                self.assertNoHoliday(holidays, (f"{year}-11-01" for year in self.full_range))
                 self.assertNoHolidayName(name, holidays)
 
     def test_genevan_fast(self):
@@ -558,10 +582,10 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv in subdivs_that_have:
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-12-08" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-12-08" for year in self.full_range)
                 )
             else:
-                self.assertNoHoliday(holidays, (f"{year}-12-08" for year in range(1970, 2050)))
+                self.assertNoHoliday(holidays, (f"{year}-12-08" for year in self.full_range))
                 self.assertNoHolidayName(name, holidays)
 
     def test_saint_stephens_day(self):
@@ -583,7 +607,10 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         }
         subdivs_optional = {"FR", "NW", "OW", "VS", "ZG"}
         subdivs_that_dont = (
-            set(CH.subdivisions) - subdivs_that_have - subdivs_optional - {"AI", "AR", "NE", "UR"}
+            set(Switzerland.subdivisions)
+            - subdivs_that_have
+            - subdivs_optional
+            - {"AI", "AR", "NE", "UR"}
         )
 
         self.assertNoHolidayName(name)
@@ -591,19 +618,19 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv in subdivs_that_have:
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-12-26" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-12-26" for year in self.full_range)
                 )
             elif subdiv in subdivs_that_dont:
-                self.assertNoHoliday(holidays, (f"{year}-12-26" for year in range(1970, 2050)))
+                self.assertNoHoliday(holidays, (f"{year}-12-26" for year in self.full_range))
                 self.assertNoHolidayName(name, holidays)
 
-        for subdiv, holidays in self.subdiv_holidays_optional.items():
+        for subdiv, holidays in self.subdiv_optional_holidays.items():
             if subdiv in subdivs_optional:
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-12-26" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-12-26" for year in self.full_range)
                 )
             else:
-                self.assertNoHoliday(holidays, (f"{year}-12-26" for year in range(1970, 2050)))
+                self.assertNoHoliday(holidays, (f"{year}-12-26" for year in self.full_range))
                 self.assertNoHolidayName(name, holidays)
 
         # When holiday present in NE.
@@ -613,7 +640,7 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         )
         self.assertNoHoliday(
             self.subdiv_holidays["NE"],
-            (f"{year}-12-26" for year in set(range(1970, 2050)).difference(ne_years_have)),
+            (f"{year}-12-26" for year in set(self.full_range).difference(ne_years_have)),
         )
 
         # When holiday not present in AI, AR, UR.
@@ -646,7 +673,7 @@ class TestSwitzerland(CommonCountryTests, TestCase):
             self.assertHolidayName(
                 name,
                 self.subdiv_holidays[subdiv],
-                set(range(1970, 2050)).difference(ai_ar_ur_years_dont),
+                set(self.full_range).difference(ai_ar_ur_years_dont),
             )
             self.assertNoHoliday(
                 self.subdiv_holidays[subdiv],
@@ -661,10 +688,259 @@ class TestSwitzerland(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "GE":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-12-31" for year in range(1970, 2050))
+                    name, holidays, (f"{year}-12-31" for year in self.full_range)
+                )
+            else:
+                self.assertNoHoliday(holidays, (f"{year}-12-31" for year in self.full_range))
+                self.assertNoHolidayName(name, holidays)
+
+    def test_knabenschiessen(self):
+        name = "Knabenschiessen"
+
+        self.assertNoHolidayName(name)
+
+        for subdiv, holidays in self.subdiv_holidays.items():
+            if subdiv == "ZH":
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "2020-09-12",
+                    "2020-09-13",
+                    "2021-09-11",
+                    "2021-09-12",
+                    "2022-09-10",
+                    "2022-09-11",
+                    "2023-09-09",
+                    "2023-09-10",
+                    "2024-09-07",
+                    "2024-09-08",
+                    "2025-09-13",
+                    "2025-09-14",
+                )
+                self.assertHolidayNameCount(name, 2, holidays, self.full_range)
+            else:
+                self.assertNoHolidayName(name, holidays)
+
+        for subdiv, holidays in self.subdiv_half_day_holidays.items():
+            if subdiv == "ZH":
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "2020-09-14",
+                    "2021-09-13",
+                    "2022-09-12",
+                    "2023-09-11",
+                    "2024-09-09",
+                    "2025-09-15",
+                )
+                self.assertHolidayName(name, holidays, self.full_range)
+            else:
+                self.assertNoHolidayName(name, holidays)
+
+        for subdiv, holidays in self.subdiv_optional_holidays.items():
+            if subdiv == "ZH":
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "2020-09-14",
+                    "2023-09-11",
+                    "2024-09-09",
+                    "2025-09-15",
+                )
+                self.assertNoHolidayName(
+                    name,
+                    holidays,
+                    # Not in years where 4 bridge holidays are given out for Christmas-New Year.
+                    "2016-09-12",
+                    "2021-09-13",
+                    "2022-09-12",
+                    "2027-09-13",
+                )
+            else:
+                self.assertNoHolidayName(name, holidays)
+
+        self.assertNoHolidayName(name, Switzerland(subdiv="ZH", years=1898))
+        self.assertNoHolidayName(name, Switzerland(categories=HALF_DAY, subdiv="ZH", years=1898))
+        self.assertNoHolidayName(name, Switzerland(categories=OPTIONAL, subdiv="ZH", years=1898))
+
+    def test_day_before_good_friday(self):
+        name = "Vortag vor Karfreitag"
+
+        self.assertNoHolidayName(name)
+
+        for subdiv, holidays in {
+            **self.subdiv_half_day_holidays,
+            **self.subdiv_optional_holidays,
+        }.items():
+            if subdiv == "ZH":
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "2020-04-09",
+                    "2021-04-01",
+                    "2022-04-14",
+                    "2023-04-06",
+                    "2024-03-28",
+                    "2025-04-17",
+                )
+                self.assertHolidayName(name, holidays, self.full_range)
+            else:
+                self.assertNoHolidayName(name, holidays)
+
+    def test_sechselauten(self):
+        name = "Sechseläuten"
+
+        self.assertNoHolidayName(name)
+
+        for subdiv, holidays in {
+            **self.subdiv_half_day_holidays,
+            **self.subdiv_optional_holidays,
+        }.items():
+            if subdiv == "ZH":
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "2020-04-20",
+                    "2021-04-19",
+                    "2022-04-25",
+                    "2023-04-17",
+                    "2024-04-15",
+                    "2025-04-28",
+                )
+                self.assertHolidayName(name, holidays, self.full_range)
+            else:
+                self.assertNoHolidayName(name, holidays)
+
+        subdiv_zh_half_day_holidays = Switzerland(
+            categories=HALF_DAY, subdiv="ZH", years=range(1901, 1970)
+        )
+
+        self.assertHolidayName(
+            name,
+            subdiv_zh_half_day_holidays,
+            "1902-03-24",
+            "1903-03-23",
+            "1904-03-21",
+            "1949-03-21",
+            "1950-03-27",
+            "1951-03-26",
+            "1952-04-21",
+        )
+        self.assertHolidayName(name, subdiv_zh_half_day_holidays, range(1902, 1970))
+        self.assertNoHolidayName(name, subdiv_zh_half_day_holidays, 1901)
+
+        subdiv_zh_optional_holidays = Switzerland(
+            categories=OPTIONAL, subdiv="ZH", years=range(1901, 1970)
+        )
+
+        self.assertHolidayName(
+            name,
+            subdiv_zh_optional_holidays,
+            "1902-03-24",
+            "1903-03-23",
+            "1904-03-21",
+            "1949-03-21",
+            "1950-03-27",
+            "1951-03-26",
+            "1952-04-21",
+        )
+        self.assertHolidayName(name, subdiv_zh_optional_holidays, range(1902, 1970))
+        self.assertNoHolidayName(name, subdiv_zh_optional_holidays, 1901)
+
+    def test_day_before_ascension_day(self):
+        name = "Vortag vor Auffahrt"
+
+        self.assertNoHolidayName(name)
+
+        for subdiv, holidays in self.subdiv_half_day_holidays.items():
+            if subdiv == "ZH":
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "2020-05-20",
+                    "2021-05-12",
+                    "2022-05-25",
+                    "2023-05-17",
+                    "2024-05-08",
+                    "2025-05-28",
+                )
+                self.assertHolidayName(name, holidays, self.full_range)
+            else:
+                self.assertNoHolidayName(name, holidays)
+
+    def test_bridge_holiday_for_ascension_day(self):
+        name = "Brückentag nach Auffahrt"
+
+        self.assertNoHolidayName(name)
+
+        for subdiv, holidays in self.subdiv_optional_holidays.items():
+            if subdiv == "ZH":
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "2018-05-11",
+                    "2019-05-31",
+                    "2024-05-10",
+                    "2025-05-30",
+                )
+            else:
+                self.assertNoHolidayName(name, holidays)
+
+    def test_christmas_eve(self):
+        name = "Heiligabend"
+
+        self.assertNoHolidayName(name)
+
+        for subdiv, holidays in {
+            **self.subdiv_half_day_holidays,
+            **self.subdiv_optional_holidays,
+        }.items():
+            if subdiv == "ZH":
+                self.assertHolidayName(
+                    name, holidays, (f"{year}-12-24" for year in self.full_range)
+                )
+            else:
+                self.assertNoHolidayName(name, holidays)
+
+    def test_bridge_holidays(self):
+        name = "Brückentag"
+
+        self.assertNoHolidayName(name)
+
+        for subdiv, holidays in self.subdiv_optional_holidays_non_observed.items():
+            if subdiv == "ZH":
+                self.assertNonObservedHolidayName(
+                    name,
+                    holidays,
+                    (f"{year}-12-27" for year in self.full_range),
+                    (f"{year}-12-28" for year in self.full_range),
+                    (f"{year}-12-29" for year in self.full_range),
+                    (f"{year}-12-30" for year in self.full_range),
+                )
+            else:
+                self.assertNoNonObservedHolidayName(name, holidays)
+
+        self.assertNoHoliday(
+            self.subdiv_optional_holidays["ZH"],
+            "2025-12-27",
+            "2025-12-28",
+            "2026-12-27",
+        )
+
+    def test_new_years_eve(self):
+        name = "Vortag vor Neujahr"
+
+        self.assertNoHolidayName(name)
+
+        for subdiv, holidays in {
+            **self.subdiv_half_day_holidays,
+            **self.subdiv_optional_holidays,
+        }.items():
+            if subdiv == "ZH":
+                self.assertHolidayName(
+                    name, holidays, (f"{year}-12-31" for year in self.full_range)
                 )
             else:
-                self.assertNoHoliday(holidays, (f"{year}-12-31" for year in range(1970, 2050)))
                 self.assertNoHolidayName(name, holidays)
 
     def test_l10n_default(self):
@@ -674,10 +950,13 @@ class TestSwitzerland(CommonCountryTests, TestCase):
             ("2023-01-06", "Heilige Drei Könige"),
             ("2023-03-01", "Jahrestag der Ausrufung der Republik"),
             ("2023-03-19", "Josefstag"),
+            ("2023-04-06", "Vortag vor Karfreitag"),
             ("2023-04-07", "Karfreitag"),
             ("2023-04-10", "Ostermontag"),
             ("2023-04-13", "Näfelser Fahrt"),
+            ("2023-04-17", "Sechseläuten"),
             ("2023-05-01", "Tag der Arbeit"),
+            ("2023-05-17", "Vortag vor Auffahrt"),
             ("2023-05-18", "Auffahrt"),
             ("2023-05-29", "Pfingstmontag"),
             ("2023-06-08", "Fronleichnam"),
@@ -686,13 +965,20 @@ class TestSwitzerland(CommonCountryTests, TestCase):
             ("2023-08-01", "Nationalfeiertag"),
             ("2023-08-15", "Mariä Himmelfahrt"),
             ("2023-09-07", "Genfer Bettag"),
+            ("2023-09-09", "Knabenschiessen"),
+            ("2023-09-10", "Knabenschiessen"),
+            ("2023-09-11", "Knabenschiessen"),
             ("2023-09-18", "Bettagsmontag"),
             ("2023-09-25", "Bruder Klaus"),
             ("2023-11-01", "Allerheiligen"),
             ("2023-12-08", "Mariä Empfängnis"),
+            ("2023-12-24", "Heiligabend"),
             ("2023-12-25", "Weihnachten"),
             ("2023-12-26", "Stephanstag"),
-            ("2023-12-31", "Wiederherstellung der Republik"),
+            ("2023-12-27", "Brückentag"),
+            ("2023-12-28", "Brückentag"),
+            ("2023-12-29", "Brückentag"),
+            ("2023-12-31", "Vortag vor Neujahr; Wiederherstellung der Republik"),
         )
 
     def test_l10n_en_us(self):
@@ -703,10 +989,13 @@ class TestSwitzerland(CommonCountryTests, TestCase):
             ("2023-01-06", "Epiphany"),
             ("2023-03-01", "Republic Day"),
             ("2023-03-19", "Saint Joseph's Day"),
+            ("2023-04-06", "Day before Good Friday"),
             ("2023-04-07", "Good Friday"),
             ("2023-04-10", "Easter Monday"),
             ("2023-04-13", "Battle of Naefels Victory Day"),
+            ("2023-04-17", "Sechseläuten"),
             ("2023-05-01", "Labor Day"),
+            ("2023-05-17", "Day before Ascension Day"),
             ("2023-05-18", "Ascension Day"),
             ("2023-05-29", "Whit Monday"),
             ("2023-06-08", "Corpus Christi"),
@@ -715,13 +1004,20 @@ class TestSwitzerland(CommonCountryTests, TestCase):
             ("2023-08-01", "National Day"),
             ("2023-08-15", "Assumption Day"),
             ("2023-09-07", "Genevan Fast"),
+            ("2023-09-09", "Knabenschiessen"),
+            ("2023-09-10", "Knabenschiessen"),
+            ("2023-09-11", "Knabenschiessen"),
             ("2023-09-18", "Prayer Monday"),
             ("2023-09-25", "Saint Nicholas of Flüe"),
             ("2023-11-01", "All Saints' Day"),
             ("2023-12-08", "Immaculate Conception"),
+            ("2023-12-24", "Christmas Eve"),
             ("2023-12-25", "Christmas Day"),
             ("2023-12-26", "Saint Stephen's Day"),
-            ("2023-12-31", "Restoration Day"),
+            ("2023-12-27", "Bridge Holiday"),
+            ("2023-12-28", "Bridge Holiday"),
+            ("2023-12-29", "Bridge Holiday"),
+            ("2023-12-31", "New Year's Eve; Restoration Day"),
         )
 
     def test_l10n_fr(self):
@@ -732,10 +1028,13 @@ class TestSwitzerland(CommonCountryTests, TestCase):
             ("2023-01-06", "Épiphanie"),
             ("2023-03-01", "Instauration de la République"),
             ("2023-03-19", "Saint-Joseph"),
+            ("2023-04-06", "Veille du Vendredi saint"),
             ("2023-04-07", "Vendredi saint"),
             ("2023-04-10", "Lundi de Pâques"),
             ("2023-04-13", "Fahrtsfest"),
+            ("2023-04-17", "Sechseläuten"),
             ("2023-05-01", "Fête du Travail"),
+            ("2023-05-17", "Veille de l'Ascension"),
             ("2023-05-18", "Ascension"),
             ("2023-05-29", "Lundi de Pentecôte"),
             ("2023-06-08", "Fête-Dieu"),
@@ -744,13 +1043,20 @@ class TestSwitzerland(CommonCountryTests, TestCase):
             ("2023-08-01", "Fête nationale"),
             ("2023-08-15", "Assomption"),
             ("2023-09-07", "Jeûne genevois"),
+            ("2023-09-09", "Knabenschiessen"),
+            ("2023-09-10", "Knabenschiessen"),
+            ("2023-09-11", "Knabenschiessen"),
             ("2023-09-18", "Lundi du Jeûne fédéral"),
             ("2023-09-25", "Fête de Saint-Nicolas-de-Flüe"),
             ("2023-11-01", "Toussaint"),
             ("2023-12-08", "Immaculée Conception"),
+            ("2023-12-24", "Veille de Noël"),
             ("2023-12-25", "Noël"),
             ("2023-12-26", "Saint-Étienne"),
-            ("2023-12-31", "Restauration de la République"),
+            ("2023-12-27", "Jour pont"),
+            ("2023-12-28", "Jour pont"),
+            ("2023-12-29", "Jour pont"),
+            ("2023-12-31", "Restauration de la République; Réveillon du Nouvel An"),
         )
 
     def test_l10n_it(self):
@@ -761,10 +1067,13 @@ class TestSwitzerland(CommonCountryTests, TestCase):
             ("2023-01-06", "Epifania"),
             ("2023-03-01", "Giorno della Repubblica"),
             ("2023-03-19", "San Giuseppe"),
+            ("2023-04-06", "Vigilia del Venerdì Santo"),
             ("2023-04-07", "Venerdì Santo"),
             ("2023-04-10", "Lunedì dell'Angelo"),
             ("2023-04-13", "Battaglia di Näfels"),
+            ("2023-04-17", "Sechseläuten"),
             ("2023-05-01", "Festa del lavoro"),
+            ("2023-05-17", "Vigilia dell'Ascensione di Gesù"),
             ("2023-05-18", "Ascensione di Gesù"),
             ("2023-05-29", "Lunedì di Pentecoste"),
             ("2023-06-08", "Corpus Domini"),
@@ -772,14 +1081,60 @@ class TestSwitzerland(CommonCountryTests, TestCase):
             ("2023-06-29", "Santi Pietro e Paolo"),
             ("2023-08-01", "Festa nazionale"),
             ("2023-08-15", "Assunzione di Maria"),
-            ("2023-09-07", "Jeûne genevois"),
-            ("2023-09-18", "Digiuno Ginevrino"),
-            ("2023-09-25", "Nicolao della Flüe"),
+            ("2023-09-07", "Digiuno ginevrino"),
+            ("2023-09-09", "Knabenschiessen"),
+            ("2023-09-10", "Knabenschiessen"),
+            ("2023-09-11", "Knabenschiessen"),
+            ("2023-09-18", "Lunedì del digiuno federal"),
+            ("2023-09-25", "San Nicolao della Flue"),
             ("2023-11-01", "Ognissanti"),
             ("2023-12-08", "Immacolata Concezione"),
+            ("2023-12-24", "Vigilia di Natale"),
             ("2023-12-25", "Natale"),
             ("2023-12-26", "Giorno di Santo Stefano"),
-            ("2023-12-31", "Restauration genevoise"),
+            ("2023-12-27", "Giorno ponte"),
+            ("2023-12-28", "Giorno ponte"),
+            ("2023-12-29", "Giorno ponte"),
+            ("2023-12-31", "Restaurazione della Repubblica; Vigilia di Capodanno"),
+        )
+
+    def test_l10n_th(self):
+        self.assertLocalizedHolidays(
+            "th",
+            ("2023-01-01", "วันขึ้นปีใหม่"),
+            ("2023-01-02", "วันสมโภชนักบุญแบร์กโทลด์"),
+            ("2023-01-06", "วันสมโภชพระคริสต์แสดงองค์"),
+            ("2023-03-01", "วันครบรอบการสถาปนาสาธารณรัฐนอยชาแตล"),
+            ("2023-03-19", "วันสมโภชนักบุญโยเซฟ"),
+            ("2023-04-06", "วันก่อนวันศุกร์ประเสริฐ"),
+            ("2023-04-07", "วันศุกร์ประเสริฐ"),
+            ("2023-04-10", "วันจันทร์อีสเตอร์"),
+            ("2023-04-13", "วันรำลึกชัยชนะยุทธการเนเฟลส์"),
+            ("2023-04-17", "เซ็กเซ่ะเล๊าเท่น"),
+            ("2023-05-01", "วันแรงงาน"),
+            ("2023-05-17", "วันก่อนวันสมโภชพระเยซูเจ้าเสด็จขึ้นสวรรค์"),
+            ("2023-05-18", "วันสมโภชพระเยซูเจ้าเสด็จขึ้นสวรรค์"),
+            ("2023-05-29", "วันจันทร์หลังวันสมโภชพระจิตเจ้า"),
+            ("2023-06-08", "วันสมโภชพระคริสตวรกาย"),
+            ("2023-06-23", "วันประกาศเอกราชจูรา"),
+            ("2023-06-29", "วันสมโภชนักบุญเปโตรและเปาโล"),
+            ("2023-08-01", "วันชาติสวิตเซอร์แลนด์"),
+            ("2023-08-15", "วันสมโภชแม่พระรับเกียรติยกขึ้นสวรรค์"),
+            ("2023-09-07", "วันถือศีลอดเจนีวา"),
+            ("2023-09-09", "คนาเบนชิสเซน"),
+            ("2023-09-10", "คนาเบนชิสเซน"),
+            ("2023-09-11", "คนาเบนชิสเซน"),
+            ("2023-09-18", "วันจันทร์แห่งการอธิษฐาน"),
+            ("2023-09-25", "วันสมโภชนักบุญนิโคลัสแห่งฟลือเออ"),
+            ("2023-11-01", "วันสมโภชนักบุญทั้งหลาย"),
+            ("2023-12-08", "วันสมโภชแม่พระผู้ปฏิสนธินิรมล"),
+            ("2023-12-24", "วันคริสต์มาสอีฟ"),
+            ("2023-12-25", "วันคริสต์มาส"),
+            ("2023-12-26", "วันสมโภชนักบุญสเตเฟน"),
+            ("2023-12-27", "วันหยุดเพิ่มเติม"),
+            ("2023-12-28", "วันหยุดเพิ่มเติม"),
+            ("2023-12-29", "วันหยุดเพิ่มเติม"),
+            ("2023-12-31", "วันกอบกู้เอกราชสาธารณรัฐเจนีวา; วันสิ้นปี"),
         )
 
     def test_l10n_uk(self):
@@ -790,10 +1145,13 @@ class TestSwitzerland(CommonCountryTests, TestCase):
             ("2023-01-06", "Богоявлення"),
             ("2023-03-01", "Річниця проголошення Республіки"),
             ("2023-03-19", "День Святого Йосипа"),
+            ("2023-04-06", "Переддень Страсної пʼятниці"),
             ("2023-04-07", "Страсна пʼятниця"),
             ("2023-04-10", "Великодній понеділок"),
             ("2023-04-13", "Свято перемоги під Нефельсом"),
+            ("2023-04-17", "Зексельйотен"),
             ("2023-05-01", "День праці"),
+            ("2023-05-17", "Переддень Вознесіння Господнього"),
             ("2023-05-18", "Вознесіння Господнє"),
             ("2023-05-29", "День Святого Духа"),
             ("2023-06-08", "Свято Тіла і Крові Христових"),
@@ -802,11 +1160,18 @@ class TestSwitzerland(CommonCountryTests, TestCase):
             ("2023-08-01", "Національне свято"),
             ("2023-08-15", "Внебовзяття Пресвятої Діви Марії"),
             ("2023-09-07", "Женевський піст"),
+            ("2023-09-09", "Кнабеншісен"),
+            ("2023-09-10", "Кнабеншісен"),
+            ("2023-09-11", "Кнабеншісен"),
             ("2023-09-18", "Молитовний понеділок"),
             ("2023-09-25", "День Святого Ніклауса з Флюе"),
             ("2023-11-01", "День усіх святих"),
             ("2023-12-08", "Непорочне зачаття Діви Марії"),
+            ("2023-12-24", "Святий вечір"),
             ("2023-12-25", "Різдво Христове"),
             ("2023-12-26", "День Святого Стефана"),
-            ("2023-12-31", "День відновлення республіки"),
+            ("2023-12-27", "Проміжний вихідний"),
+            ("2023-12-28", "Проміжний вихідний"),
+            ("2023-12-29", "Проміжний вихідний"),
+            ("2023-12-31", "День відновлення республіки; Переддень Нового року"),
         )
