@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -676,22 +676,19 @@ class TestUkraine(CommonCountryTests, WorkingDayTests, TestCase):
             ("2021-03-08", "اليوم العالمي للمرأة"),
             ("2021-05-01", "عيد العمال"),
             ("2021-05-02", "عيد الفصح"),
-            ("2021-05-03", "(يوم عطلة) عيد العمال"),
-            ("2021-05-04", "(يوم عطلة) عيد الفصح"),
+            ("2021-05-03", "عيد العمال (ملاحظة)"),
+            ("2021-05-04", "عيد الفصح (ملاحظة)"),
             ("2021-05-09", "يوم النصر على النازية في الحرب العالمية الثانية (يوم النصر)"),
-            (
-                "2021-05-10",
-                "(يوم عطلة) يوم النصر على النازية في الحرب العالمية الثانية (يوم النصر)",
-            ),
+            ("2021-05-10", "يوم النصر على النازية في الحرب العالمية الثانية (يوم النصر) (ملاحظة)"),
             ("2021-06-20", "الثالوث"),
-            ("2021-06-21", "(يوم عطلة) الثالوث"),
+            ("2021-06-21", "الثالوث (ملاحظة)"),
             ("2021-06-28", "يوم الدستور في أوكرانيا"),
             ("2021-08-23", "يوم عطلة (استبدل من 28/08/2021)"),
             ("2021-08-24", "عيد استقلال أوكرانيا"),
             ("2021-10-14", "يوم المدافعين عن أوكرانيا"),
             ("2021-10-15", "يوم عطلة (استبدل من 23/10/2021)"),
             ("2021-12-25", "عيد الميلاد"),
-            ("2021-12-27", "(يوم عطلة) عيد الميلاد"),
+            ("2021-12-27", "عيد الميلاد (ملاحظة)"),
         )
 
     def test_l10n_th(self):
