@@ -58,8 +58,9 @@ class TestVI(CommonCountryTests, TestCase):
             ("2022-04-14", "Holy Thursday"),
             ("2022-04-15", "Good Friday"),
             ("2022-04-18", "Easter Monday"),
+            ("2022-05-08", "Mother's Day"),
             ("2022-05-30", "Memorial Day"),
-            ("2022-06-19", "Juneteenth National Independence Day"),
+            ("2022-06-19", "Father's Day; Juneteenth National Independence Day"),
             ("2022-06-20", "Juneteenth National Independence Day (observed)"),
             ("2022-07-03", "Emancipation Day"),
             ("2022-07-04", "Independence Day"),
@@ -86,8 +87,9 @@ class TestVI(CommonCountryTests, TestCase):
             ("2022-04-14", "วันพฤหัสศักดิสิทธิ์"),
             ("2022-04-15", "วันศุกร์ประเสริฐ"),
             ("2022-04-18", "วันจันทร์อีสเตอร์"),
+            ("2022-05-08", "วันแม่"),
             ("2022-05-30", "วันรำลึก"),
-            ("2022-06-19", "วันประกาศอิสรภาพแห่งชาติจูนทีนท์"),
+            ("2022-06-19", "วันประกาศอิสรภาพแห่งชาติจูนทีนท์; วันพ่อ"),
             ("2022-06-20", "ชดเชยวันประกาศอิสรภาพแห่งชาติจูนทีนท์"),
             ("2022-07-03", "วันเลิกทาส"),
             ("2022-07-04", "วันประกาศอิสรภาพ"),
