@@ -40,7 +40,7 @@ class EntityStubStaticHolidays:
 
 
 class EntityStub(HolidayBase):
-    def _add_observed(self, dt: date, before: bool = True, after: bool = True) -> None:
+    def _add_observed(self, dt: date, *, before: bool = True, after: bool = True) -> None:
         if not self.observed:
             return None
 
@@ -567,23 +567,31 @@ class TestHelperMethods(unittest.TestCase):
         self.hb.weekend = {MON, TUE}
         for dt in dts:
             self.assertTrue(self.hb._is_weekend(dt))
+            self.assertFalse(self.hb._is_weekday(dt))
 
         self.hb.weekend = {}
         for dt in dts:
             self.assertFalse(self.hb._is_weekend(dt))
+            self.assertTrue(self.hb._is_weekday(dt))
 
         self.hb.weekend = {SAT, SUN}
         for dt in (date(2022, 10, 1), date(2022, 10, 2)):
             self.assertTrue(self.hb._is_weekend(dt))
+            self.assertFalse(self.hb._is_weekday(dt))
         for dt in ((OCT, 1), (OCT, 2)):
             self.assertTrue(self.hb._is_weekend(dt))
             self.assertTrue(self.hb._is_weekend(*dt))
+            self.assertFalse(self.hb._is_weekday(dt))
+            self.assertFalse(self.hb._is_weekday(*dt))
 
         for dt in (date(2022, 10, 3), date(2022, 10, 4)):
             self.assertFalse(self.hb._is_weekend(dt))
+            self.assertTrue(self.hb._is_weekday(dt))
         for dt in ((OCT, 3), (OCT, 4)):
             self.assertFalse(self.hb._is_weekend(dt))
             self.assertFalse(self.hb._is_weekend(*dt))
+            self.assertTrue(self.hb._is_weekday(dt))
+            self.assertTrue(self.hb._is_weekday(*dt))
 
 
 class TestHolidaySum(unittest.TestCase):
@@ -1228,7 +1236,7 @@ class TestSubstitutedHolidays(unittest.TestCase):
         for cls in (EmptySubstitutedHolidays, NoSubstitutedHolidays):
             hb = self.CountryStub(cls=cls)
             self.assertFalse(hb.has_special_holidays)
-            self.assertTrue(hb.has_substituted_holidays)
+            self.assertFalse(hb.has_substituted_holidays)
 
             hb._populate(1991)
             self.assertNotIn("1991-01-07", hb)
